Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows and
# no contrary --with/--without arguments are given on the command line.

%define buildup 1
%define buildsmp 0
%define buildBOOT 0
%define buildbigmem 0
%define buildjensen 0




# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock RHL kernel, for example by
# adding some text to the end of the version number.
#
%define release ipsec199_0.9.27_mppe1_8
%define sublevel 20
%define freeswan_version 1.99
%define x509_version 0.9.27
%define kversion 2.4.%{sublevel}
# /usr/src/%{kslnk} -> /usr/src/linux-%{KVERREL}
%define kslnk linux-2.4

# groups of related archs
%define all_x86 i386 i686 i586 athlon
#define all_x86 i686 i386 i586 athlon

%define nptlarchs %{all_x86}

# disable build root strip policy
%define __spec_install_post /usr/lib/rpm/brp-compress || :
#
# RPM foo magic
%define _missing_doc_files_terminate_build    0
%define _unpackaged_files_terminate_build 0
%define debug_package %{nil}

# Enable this to build a board-specific kernel configuration 
# some architectures have LOTS of different setups and this 
# is a way to deal with that cleanly.
#
#define targetboard assabet
%define dashtargetboard %{?targetboard:-%{targetboard}}
%define withtargetboard 0
%{?targetboard: %{expand: %%define withtargetboard 1}}
	
# Override generic defaults with per-arch defaults (which can
# themselves be overridden with --with/--without).  These must
# ONLY be "0", never "1"

# First, architecture-specific kernels off on all other archs (ifnarch)
%ifnarch i686
%define buildbigmem 0
%endif
%ifnarch alpha
# jensen kernel, only for alpha.  Old, broken broken alpha.
%define buildjensen 0
%endif
%ifnarch i386 alpha 
%define buildBOOT 0
%endif
# For board-specific kernels, build only the normal kernel (which may actually be smp, not up).
%if %{withtargetboard}
%define buildsmp 0
%define buildBOOT 0
%define buildbigmem 0
%define buildjensen 0
%endif

# Second, per-architecture exclusions (ifarch)
%ifarch i386
%define buildsmp 0
%define buildup 0
%endif
%ifarch i586
%define buildsmp 0
%endif
%ifarch ia64
%define buildBOOT 0
%endif


# we can't test values inline, only whether a macro exists
%{expand: %%define buildup_%{buildup} yadda}
%{expand: %%define buildsmp_%{buildsmp} yadda}
%{expand: %%define buildBOOT_%{buildBOOT} yadda}
%{expand: %%define buildbigmem_%{buildbigmem} yadda}
%{expand: %%define buildjensen_%{buildjensen} yadda}
%{expand: %%define ikd_%{ikd} yadda}
%{expand: %%define ibcs_%{ibcs} yadda}
%{expand: %%define debuglevel_%{debugging} yadda}

%{expand: %%define kernel_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 0.3.1, cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, e2fsprogs < 1.22, initscripts < 6.41, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0, oprofile < 0.4, SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13}


%define BOOT_kernel_prereq fileutils, modutils >=  2.4.18
%define kernel_prereq %{BOOT_kernel_prereq}, initscripts >= 5.83, mkinitrd >= 3.2.6
%ifarch ia64
%define initrd_dir /boot/efi/redhat
%else
%define initrd_dir /boot
%endif

%ifarch %{all_x86} x86_64
%define kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch ia64
# <sigh>, no GLOB_BRACE for filelists, efi needs to be done separately
%define kernel_glob vmlinuz-%{KVERREL}
%endif
%ifarch alpha
%define kernel_glob vmlinu?-%{KVERREL}
%endif

Name: kernel
Version: %{kversion}
Release: %{release}%{?targetboard:%{targetboard}}%{?debuglevel_1:.dbg}
%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
License: GPL
Group: System Environment/Kernel
ExclusiveArch: %{all_x86} x86_64
ExclusiveOS: Linux
Obsoletes: kernel-modules, kernel-sparc
Provides: module-info, kernel = %{version}
# BuildProvides: rhbuildsys(ParallelBuild) <= 8
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%ifarch %{all_x86} ia64 x86_64
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0, kernel-drm = 4.2.99.3
%endif
Autoreqprov: no
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

BuildPreReq: modutils >= 2.4.21-1, patch >= 2.5.4, bash >= 2.03, sh-utils, gnupg, tar
BuildPreReq: bzip2, findutils, dev, gzip, m4


BuildRequires: gcc >= 2.96-98

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-%{kversion}.tar.bz2
Source5: ftp://ftp.xs4all.nl/pub/crypto/freeswan/freeswan-%{freeswan_version}.tar.gz
Source6: http://www.strongsec.com/freeswan/x509patch-%{x509_version}-freeswan-%{freeswan_version}.tar.gz
Source7: freeswan.make.patch.tar
Source8: Makefile.inc.diff.tar


Source10: COPYING.modules
Source11: module-info
Source14: kernel-2.4-BuildASM.sh
Source15: linux-rhconfig.h
Source16: linux-merge-config.awk
Source17: linux-merge-modules.awk
Source18: genkey
Source19: device.awk

Source20: kernel-%{kversion}-i386.config
Source21: kernel-%{kversion}-i386-smp.config
Source22: kernel-%{kversion}-i386-BOOT.config
Source23: kernel-%{kversion}-alpha.config
Source24: kernel-%{kversion}-alpha-smp.config
Source25: kernel-%{kversion}-sparc.config
Source26: kernel-%{kversion}-sparc-smp.config
Source27: kernel-%{kversion}-sparc64.config
Source28: kernel-%{kversion}-sparc64-smp.config
Source29: kernel-%{kversion}-i686.config
Source30: kernel-%{kversion}-i686-smp.config
Source31: kernel-%{kversion}-alpha-BOOT.config
Source32: kernel-%{kversion}-sparc-BOOT.config
Source33: kernel-%{kversion}-sparc64-BOOT.config
Source34: kernel-%{kversion}-i586.config
Source35: kernel-%{kversion}-i586-smp.config
# since there are no space issues, a -BOOT is rather pointless
Source36: kernel-%{kversion}-ia64.config
Source37: kernel-%{kversion}-ia64-smp.config
Source38: kernel-%{kversion}-i686-bigmem.config
Source40: kernel-%{kversion}-athlon.config
Source41: kernel-%{kversion}-athlon-smp.config
Source42: kernel-%{kversion}-alpha-jensen.config
Source47: kernel-%{kversion}-ia64-BOOT.config
Source48: kernel-%{kversion}-x86_64.config
Source49: kernel-%{kversion}-x86_64-smp.config
Source50: installkernel.iSeries
Source51: installcmdline.iSeries

# the following is for embedded systems where the %{targetboard} variable
# is set
%if %{withtargetboard}
Source70: kernel-%{kversion}-%{_target_cpu}-%{targetboard}.config
%endif

####Source80: linux-2.4.7-ikd.patch

#
# Patches 0 through 100 are meant for core subsystem upgrades
#

Patch1: patch-2.4.21-pre3.bz2
Patch2: linux-2.4.20-selected-ac-bits.patch
Patch3: linux-2.4.18-unselected-ac-bits.patch
Patch4: linux-2.4.18-noramfs.patch

# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# IA64


# Alpha


# Sparc / Sparc64

# x86

Patch200: linux-2.4.20-amd-golem.patch

# X86-64 is 220 - 239

Patch220: linux-2.4.20-x86_64.patch
Patch221: linux-2.4.20-x86_64-fixes.patch

# arm

# sh

# mips


#
# Patches 400 through 599 are the TUX patches
#

Patch400: linux-2.4.15-tux2.patch


#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#

Patch600: linux-2.4.0-nonintconfig.patch
Patch611: linux-2.4.18-cpu-partitioning.patch
Patch620: linux-2.4.18-flock.patch
Patch630: linux-2.4.7-quotareturn.patch
Patch640: linux-2.2.16-rhconfig.patch
Patch650: linux-2.4.2-changeloop.patch
Patch651: linux-2.4.18-loopfixes.patch
Patch660: linux-2.4.20-edd.patch
Patch661: linux-2.4.20-edd-allocate.patch
Patch670: linux-2.4.20-modulealloc.patch
Patch680: linux-2.4.20-intel-acpi-safe-update.patch
Patch681: linux-2.4.20-acpi-relaxed-aml.patch
Patch682: linux-2.4.20-acpi-fixes.patch
Patch690: linux-2.4.20-ldt.patch
Patch700: linux-2.4.2-scsi_scan.patch
Patch720: linux-2.4.9-kksymoops.patch
Patch721: linux-2.4.9-kallsyms.patch
Patch740: linux-2.4.19-elevatorcache.patch
Patch750: linux-2.4.19-vmacache.patch
Patch760: linux-2.4.20-swapoff-match.patch
Patch800: linux-2.4.20-vmplayground.patch
Patch801: linux-2.4.20-pagereferenced.patch
Patch802: linux-2.4.20-statm.patch
Patch803: linux-2.4.20-rmap15c.patch
Patch804: linux-2.4.20-additional-vm-tuning.patch
Patch850: linux-2.4.18-dmi-hall-of-shame.patch
Patch860: linux-2.4.20-440gx.patch
Patch880: linux-2.4.18-sendfile64.patch
Patch890: linux-2.4.18-laptopbits.patch
Patch900: linux-2.4.20-oopsmeharder.patch

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

Patch1000: linux-2.4.18-nousb.patch
Patch1010: linux-2.4.20-silraid.patch
Patch1030: linux-2.4.0-test11-vidfail.patch
Patch1040: linux-2.4.0-e820.patch
Patch1050: linux-2.4.0-raid5xor.patch
Patch1060: linux-2.4.20-orinoco.patch
Patch1070: linux-2.4.2-page_bitmap.patch
Patch1080: linux-2.4.0-apic-quiet.patch
Patch1090: linux-2.4.20-irixnfs.patch
Patch1100: linux-2.4.3-pcipenalty.patch
Patch1110: linux-2.4.7-usb-bug50218.patch
Patch1120: linux-2.4.2-keyboardsilence.patch
Patch1130: linux-2.4.20-pwcupdate.patch
Patch1140: linux-2.4.20-lowlat.patch
Patch1150: linux-2.4.20-cpufreq.patch
Patch1170: linux-2.4.7-scsitimeout.patch
Patch1180: linux-2.4.9-freevxfs.patch
Patch1190: linux-2.4.20-drm43.patch
Patch1200: linux-2.4.9-nmiprofiling.patch
Patch1210: linux-2.4.18-moreunnamed.patch
Patch1230: linux-2.4.20-tg3.patch
Patch1240: linux-2.4.17-usb-55878.patch
Patch1250: linux-2.4.20-lvm-updates.patch
Patch1251: linux-2.4.17-lvm-bulkcopy.patch
Patch1252: linux-2.4.17-lvm-pvmove.patch
Patch1253: linux-2.4.20-mempool.patch
Patch1255: linux-2.4.18-lvm-VFSlock.patch
Patch1261: linux-2.4.18-input-35215.patch
Patch1270: linux-2.4.9-pcmcia-ethtool.patch
Patch1271: linux-2.4.18-ethtool.patch
Patch1280: linux-2.4.20-speakup.patch
Patch1290: linux-2.4.20-nicupdates.patch
Patch1300: linux-2.4.20-odirect.patch
Patch1310: linux-2.4.20-stackcoloring.patch
Patch1320: linux-2.4.20-ich5.patch
Patch1330: linux-2.4.18-scsi-whitelist.patch
Patch1340: linux-2.4.9-scsilun0.patch
Patch1350: linux-2.4.18-netdump.patch
Patch1360: linux-2.4.20-cenatek.patch
Patch1370: linux-2.4.20-serverworks.patch
Patch1380: linux-2.4.9-fstat.patch
Patch1390: linux-2.4.18-irixnfs.patch
Patch1391: linux-2.4.18-nfs-default-size.patch
Patch1400: linux-2.4.20-agpupdate.patch
Patch1410: linux-2.4.20-sbp2-smpfixes.patch
Patch1420: linux-2.4.7-suspend.patch
Patch1430: linux-2.4.20-usb.patch
Patch1450: linux-2.4.18-orinoco.patch
Patch1520: linux-2.4.19-nfs-nosvc.patch
Patch1560: linux-2.4.18-scsidevices.patch
Patch1580: linux-2.4.18-sillysymlinkfarms.patch
Patch1620: linux-2.4.18-kiobuf.patch
Patch2300: linux-2.4.9-ide-tape.patch
Patch2310: linux-2.4.18-usb-bug56856.patch
Patch2320: linux-2.4.18-usb-bug50225.patch
Patch2330: linux-2.4.20-usb-bug81091.patch
Patch2331: linux-2.4.21-pre3-usb-bug73300bis.patch
Patch2340: linux-2.4.20-usb-bug82546.patch
Patch2380: linux-2.4.17-watchdog-nowayout.patch
Patch2400: linux-2.4.18-feral-qlogic-isp.patch
Patch2410: linux-2.4.9-feral-qlogic-isp-config.patch
Patch2420: linux-2.4.18-gericom.patch
Patch2430: linux-2.4.20-oprofile.patch
Patch2431: linux-2.4.20-hyperthreading-oprofile.patch
Patch2432: linux-2.4.20-oprofile-hammer.patch
Patch2450: linux-2.4.20-pre1-nr_frags.patch
Patch2460: linux-2.4.20-andrea-fix-pausing.patch
Patch2470: linux-2.4.20-xattr-ext3.patch
Patch2471: linux-2.4.20-xattr-mbcache.patch
Patch2480: linux-2.4.20-acl.patch
Patch2481: linux-2.4.20-acl-intermezzo-fix.patch
Patch2485: linux-2.4.20-acl-xattr.patch
Patch2487: linux-2.4.20-acl-ext3.patch
Patch2488: linux-2.4.20-acl-ms-posixacl.patch
Patch2490: linux-2.4.20-ext3-updates.patch

#
# Patches 5000 to 5800 are reserved for new drivers
#
Patch5000: linux-2.4.9-addon.patch
Patch5010: linux-2.4.18-megarac.patch
Patch5020: linux-2.4.20-ipmi.patch
Patch5030: linux-2.4.18-wvlan-cs.patch
Patch5040: linux-2.4.1-netfilter-addons.patch
Patch5050: linux-2.4.18-ecc.patch
Patch5090: linux-2.4.6-bcm5820.patch
Patch5091: linux-2.4.6-bcm5820-2.patch
Patch5092: linux-2.4.7-bcm5820-16.patch
Patch5093: linux-2.4.7-bcm5820-17.patch
Patch5094: linux-2.4.18-bcm5820-update.patch
Patch5120: linux-2.4.18-iscsi.patch
Patch5180: linux-2.4.7-tulip.patch
Patch5190: linux-2.4.0-cipe-1.4.5.patch
Patch5191: linux-2.4.2-cipe.patch
Patch5192: linux-2.4.9-cipenat.patch
Patch5193: linux-2.4.18-cipe-moreinterfaces.patch
Patch5200: linux-2.4.20-lm_sensors.patch
Patch5210: linux-2.4.9-qla2200.patch
Patch5220: linux-2.4.9-aep.patch
Patch5240: linux-2.4.18-aic79xx.patch
Patch5250: linux-2.4.18-afs.patch
Patch5260: linux-2.4.18-loop-cryptoapi.patch
Patch5261: linux-2.4.18-cryptoapi.patch
Patch5270: linux-2.4.18-audigy.patch

Patch5291: linux-2.4.16-openssl-0.9.6b-mppe.patch

#
# Patches 5800 to 6000 are the HA/IPVS patches
#

#
# Patches 6000 and later are reserved for %if {something} patches
#



# debugging

Patch7000: linux-2.4.18-mmap-sem-debug.patch
Patch7001: linux-2.4.18-mmap-sem-debug-i386.patch
Patch7010: linux-2.4.18-gfp-valid.patch


#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only theese should go here. 
# Not patches you're too lazy for to put in the proper place.
#

# fix a lot of warnings in the plain kernel and previous patches
Patch10010: linux-2.4.1-compilefailure.patch

# several small tweaks not worth their own patch
Patch10020: linux-2.4.18-smallpatches.patch

# add missing MODULE_LICENSE() tags
Patch10030: linux-2.4.18-missing-license-tags.patch

# threading backport and O(1) scheduler backport; last because they need to
# be ifarch'd and touch a lot of code
Patch11000: linux-2.4.20-o1-sched+threading-backport.patch
Patch11001: linux-2.4.20-noresched.patch
Patch11002: linux-2.4.20-futex-debug.patch
Patch11003: linux-2.4.20-softlockup.patch
Patch11010: linux-2.4.20-ptrace.patch
Patch11030: linux-2.4.20-noscheduler.patch

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: gawk
Requires: gcc >= 2.96-98

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of your
Red Hat Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.
This kernel has additionally been patched with freeswan-%{freeswan_version}, x509-%{x509_version} and
MPPE openssl-0.9.6b patches.

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build custom/third party device
drivers. The source files can also be used to build a custom kernel that is
better tuned to your particular hardware, if you are so inclined (and you
know what you're doing).

%description doc
This package contains documentation files form the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: module-info, kernel = %{version}
%ifarch %{all_x86} ia64 x86_64
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0, kernel-drm = 4.2.99.3
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs, although it should
work fine on single-CPU boxes.

Install the kernel-smp package if your machine uses two or more CPUs.

%package bigmem
Summary: The Linux Kernel for machines with more than 4 Gigabyte of memory.
Group: System Environment/Kernel
Provides: module-info, kernel = %{version}
%ifarch %{all_x86} ia64 x86_64
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0, kernel-drm = 4.2.99.3
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}
Obsoletes: kernel-enterprise <= 2.4.10


%description bigmem
This package includes a kernel that has appropriate configuration options
enabled for Pentium III machines with 4 Gigabyte of memory or more.

%package BOOT
Summary: The version of the Linux kernel used on installation boot disks.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOT
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints.

%package BOOTsmp
Summary: The Linux kernel used on installation boot disks for SMP machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOTsmp
This package includes a trimmed down version of the Linux kernel. This
kernel is used on the installation boot disks only and should not be used
for an installed system, as many features in this kernel are turned off
because of the size constraints. This kernel is used when booting SMP
machines that have trouble coming up to life with the uniprocessor kernel.

%package jensen
Summary: The Linux Kernel compiled for the Alpha Jensen platform.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description jensen
This package includes a kernel that has appropriate configuration
options enabled for use on the Alpha Jensen platform.  The Jensen
platform is not supported in the normal generic alpha kernel support.

%prep

%setup -q -n %{name}-%{version} -c
# Patching FreeS/Wan with x509
%setup -D -n %{name}-%{version} -a 5
%setup -D -n %{name}-%{version} -a 6
%setup -D -n %{name}-%{version} -a 7
%setup -D -n %{name}-%{version} -a 8
cd ../%{name}-%{version}/freeswan-%{freeswan_version}
patch -p1 < ../x509patch-%{x509_version}-freeswan-%{freeswan_version}/freeswan.diff
patch Makefile.inc ../Makefile.inc.diff
cd ..
ln -s linux-%{version} linux
cd linux-%{version}

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

# update to 2.4.20-ac1
%patch1 -p1
%patch2 -p1
# and the bits we don't want removed again
%patch4 -p1

#
# User Mode Linux
# The original patch is copied (mostly) intact from Jeff's SF site,
# because he keeps changing it and we want to track that.
#
# %patch6 -p1
# %patch7 -p1

# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# IA64

# Alpha

# Sparc / Sparc64


# x86
# fix for AMD x86-64 APIC issue running x86 kernels
%patch200 -p1

#
# X86-64
#
%patch220 -p1
%patch221 -p1

# arm

# mips

#
# Patches 400 through 500 are the TUX patches
#

%patch400 -p1



#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make oldconfig_nonint" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the Red Hat buildsystem).
%patch600 -p1

#
# Allow PAM to limit certain users to certain cpu's.
#
# %patch611 -p1

#
# flock() accounting is broken; disable for 2.4 kernels
#
%patch620 -p1

# tty_write_message needs \r\n -- makes quota messages look nicer
%patch630 -p1
#
# Make "make oldconfig" smarter and have it use the config file for the
# currently running kernel as default.
#
%patch640 -p1
# Al Viro's loopback patch 
%patch650 -p1
%patch651 -p1


#
# Backport of the 2.5 EDD feature to find the boot device (used for lilo
# etc)
#
%patch660 -p1
%patch661 -p1

#
# Allocate modules not with vmalloc to reduce tlb usage
#
# %patch670 -p1
# FIXME

#
# ACPI
#
# %patch680 -p1
# %patch681 -p1
# %patch682 -p1

#
# Optimize LDT allocation to allow > 1200 threaded processes
# (Manfred Spraul; backport from 2.5)
#
%patch690 -p1

# fix lun probing on multilun RAID chassis
%patch700 -p1

#
# kksymoops - automatically decode oopses/backtraces from within the kernel
%patch720 -p1
%ifarch %{all_x86}  x86_64
%patch721 -p1
%endif

#
# Improve elevator with a one-shot cache from Stephen
#
%patch740 -p1

#
# One shot vma hole patch from Ingo
#
# %patch750 -p1

#
# Fix swapoff not to require the exact same dentry you used to swapon
#
%patch760 -p1


#
# update the list of vendors who can't program a bios
#
%patch850 -p1
#
# the 440GX bioses deserve a special nomination in this area
#
%patch860 -p1



# add sendfile64 from 2.5
%patch880 -p1

#
# add some laptop power consumption improvements
#
%patch890 -p1

# make the kernel actually oops instead of hang in a few more cases
# %patch900 -p1



#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

#
# Add a "nousb" kernel option to disable all USB loading. On some older
# machines and ACPI-only boxes trying to use ANY usb crashes the machine.
# Bug #66760.
#
%patch1000 -p1

#
# Add support for the Silicon Image(tm) Medley(tm) raid
#
%patch1010 -p1

# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer floppy that wants to automatically fall back to textmode
# in that case
%patch1030 -p1
#
# add e820 reporting in /proc; needed for anaconda to find out which
# kernels to install
#
%patch1040 -p1
# raid5 xor fix for PIII/P4, should go away shortly
%patch1050 -p1

#
# Update orinoco driver to 0.13a version; this fixed the "BAP" problem
# fix broken; patch disabled
# %patch1060 -p1

# conservative zone bitmaps to prevent potential memory corruption
%patch1070 -p1
#
# Silence the APIC errors a bit; they are harmless mostly and can happen
# in normal use.
#
%patch1080 -p1

#
# NFS patch fron trond:
# A patch that papers over a glibc bug. In glibc-2.2 and above, they use
# the new getdents64() syscall even for the 32-bit readdir. As a result, they
# have problems coping with the unsigned 64-bit d_off values that may get
# returned by some NFSv3 servers.
# NOTE: You might still have to set the '32bitclients' export option on
# some IRIX servers.

%patch1090 -p1

#
# change IRQ penalty for IRQ 12
# This tries to avoid assigning cardbus irq's to irq12 which is "special"
# for certain laptops that emulate PS/2 hardware via SMM mode.
#
%patch1100 -p1
#
# Silence the PS/2 code for USB keyboards
# It's not uncommon to have no PS/2 keyboard these days
#
%patch1120 -p1

#
# downgrade the pwc webcam driver to a working version
#
%patch1130 -p1

#
# Andrew Morton's low latency patch
#
%patch1140 -p1

#
# CPUFREQ: speedstep(tm) and powernow(tm) support
#
%patch1150 -p1

#
# make the scsi timeout longer; 30 seconds is too short for big raid arrays
# with lots of large concurrent requests in flight
#
%patch1170 -p1
#
# make freevxfs autoload when doing mount -t vxfs /dev/foo /mnt/bar
#
%patch1180 -p1

#
# DRM update
#
%patch1190 -p1

#
# use the nmi interrupt for profiling; this allows the kernel profiler
# to profile even with interrupts disabled. Note: you have to specify the
# nmi watchdog now as well for profiling to work:
# vmlinuz profile=1 nmi_watchdog=1
#
%patch1200 -p1
#
# allow more unnamed mounts by borrowing old, unused major devices
# This is needed if you want more than 255 NFS mounts; some people use the
# "one mount per user" automount setup and they need this if they have more
# than 255 users.
#
%patch1210 -p1


#
# TG3 driver updates
#
%patch1230 -p1


#
# LVM updates:
#
# add important bugfixes from Sistina's LVM-1.0.3
%patch1250 -p1
# Add bulk-copy-via-kiobufs code
%patch1251 -p1
# Add locked copy-and-remap pvmove code
%patch1252 -p1
# Add mempool code
%patch1253 -p1
#
# LVM atomic snapshot patch: quiesce the filesystem automatically when
# taking snapshots.
%patch1255 -p1
#
# Gamepad (all kbds and mice were affected, but we kludged arount it in hplug)
# autoload the proper modules
%patch1261 -p1
#
# add ethtool ioctl support to more network drivers
#
#%patch1270 -p1
#%patch1271 -p1

#
# Speakup: braille terminal things
#
# %patch1280 -p1

#
# e100 etc updates
#
%patch1290 -p1

#
# change O_DIRECT handling
#
%patch1300 -p1


#
# Improve CPU cache efficiency by coloring the cachelines of the userspace
# stack
#
%patch1310 -p1

#
# Some extra PCI ID's for newer chipsets
#
%patch1320 -p1

#
# add some devices to the scsi whitelist for multi-lun scanning
#
# %patch1330 -p1
#
# allow ioctls to lun0 even if there's no lun0 (needed for some FC kit)
#
%patch1340 -p1

#
# Netdump / Netconsole - crashdumps and kernel messages over
# the network via a lightweight UDP stack that can run with interrupts
# disabled
#
%patch1350 -p1

#
# add cenatek PCI ID's to the ide layer
#
%patch1360 -p1

# 
# Disable an advanced serverworks chipset feature because it interacts
#
%patch1370 -p1

# some broken and defective applications assume that they can fstat() on a
# pipe and meaningful interpret the value of i_size. Apparently the
# arbitrary value 2.2 put there was good enough so we try to emulate that,
# since we prefer to keep compatibility within the RHL 7.x series. This is
# a gross hack that will go away as soon as possible.
#
%patch1380 -p1
#
# IRIX seems to return 64 bit cookies for readdir. glibc uses the 64 bit
# getdents even for 32 bit readdir and then the 64 bit cookies goes awol.
# Work around this by truncating/rounding this in the kernel
#
### %patch1390 -p1
### FIXME ####
#
# NFS mounts with the default [rw]size on 2.4.18 pick up the server's max 
# size, which for some (32768) is far too large.  Instead, use the client's
# default size at 4096 if it was unspecified and the server's is larger.
#
%patch1391 -p1
#

#
# Add some PCI ID's to the agp driver
#
%patch1400 -p1

#
# Fix some firewire deadlocks (fixes from upstream maintainter)
#
%patch1410 -p1

# 
# Some bioses "forget" to restore pci config space properly on resume;
# the following patch helps them a bit with this
#
%patch1420 -p1

#
# Fix a few USB bugs
#
%patch1430 -p1

#
# Older orinoco_cs patch that fixes some laptops
#
%patch1450 -p1

#
# O_Profile
#
# %patch1480 -p1

# shut up nfs "svc: unknown version (0)" message
%patch1520 -p1 

#
# Make use of all of the 256 scsi devices available
#
%patch1560 -p1

#
# Some people build symlink farms where a symlink points to a link points to
# a link points...
# In order to avoid stack overflows, the kernel cuts of at 5 recursions.
# However some people think they need more, for those people there is
# now a stack=overflowmeharder option.
#
%patch1580 -p1

#
# Don't overly waste memory in the rawio code
#
%patch1620 -p1

# ide-tape bites back (bugs 36628, 62267)
# %patch2300 -p1
# yay alan merged it

# 56856 - SDDR-31 media check
%patch2310 -p1
# 50225 - ALi in IBM i1200
# Alan took an earlier version. Works for us too, but let's keep the slot.
#%patch2320 -p1
# 81091 - Installation BUGs when unmounting usbdevfs (workaround)
%patch2330 -p1
# 73300 (again - Marcelo has the fix for the half of it).
%patch2331 -p1
# 82546 - Yukihiro's pet, will disappear eventually
%patch2340 -p1

# feral qlogic driver patches
%patch2400 -p1
%patch2410 -p1

#
# Laptop battery monitor improvements for Gericom / Advent 7006 laptops
#
%patch2420 -p1

# oprofile backport from 2.5

%patch2430 -p1
%patch2431 -p1
%patch2432 -p1

# fix setting of nr_frags on memory allocation in the network stack
%patch2450 -p1

#
# Andrea Arcangeli's fix for a nasty stall bug
#

%patch2460 -p1

#Added Extended Attributes to extfs
# %patch2470 -p1
# %patch2471 -p1

# Added ACLs
# %patch2480 -p1
# %patch2481 -p1
# %patch2485 -p1
# %patch2487 -p1
# %patch2488 -p1

# Misc ext3 bug-fixes
%patch2490 -p1


#
# Patches 5000 to 6000 are reserved for new drivers
#
# generic drivers/addon infrastructure
%patch5000 -p1
# (ugly) driver for the Dell megarac remote access cards
%patch5010 -p1

# The linux IPMI driver
%patch5020 -p1

# Broadcom BCM5700/5701 Gigabit driver 
# wvlan_cs driver
%patch5030 -p1
# ECC reporting module
%patch5050 -p1
# Broadcom 5820 driver
%patch5090 -p1
%patch5091 -p1
%patch5092 -p1
%patch5093 -p1
%patch5094 -p1
# iSCSI driver, and fix
%patch5120 -p1

# add tulip_old driver (2.4.3 version)
%patch5180 -p1
# cipe 1.4.5
%patch5190 -p1
%patch5191 -p1
%patch5192 -p1
%patch5193 -p1
# LM-Sensors 2.6.5
%patch5200 -p1
# qla2x00
%patch5210 -p1
# AEP SSL Accelerator card
%patch5220 -p1
# aic79xx driver
%patch5240 -p1
#
# preliminary snapshot of a new AFS client
#
%patch5250 -p1

#
# Patches 5800 to 6000 are the HA/IPVS patches
#


#
# Patches 6000 and later are reserved for %if {something} patches
#

#
# Patches to support AES loop device
#
%patch5260 -p1
%patch5261 -p1

#
# Soundblaster Live! Audigy driver
#
%patch5270 -p1

# MPPE
%patch5291 -p1 
#
# debug mmap semaphore recursion deadlocks
# by keeping track of who owns what

#%patch7000 -p1
#%ifarch %{all_x86}
#%patch7001 -p1
#%endif


#
# Catch "bogus" GFP_XXXX allocation flags; those result in 
# otherwise hard to debug bugs
#
#%patch7010 -p1



#
# final stuff
#

#
# lots of small fixes to warnings and other silly bugs
#
%patch10010 -p1

# several small tweaks
%patch10020 -p1

# 
# Add MODULE_LICENSE() to the modules missing it
#
%patch10030 -p1

#
# VM Tuning: rmap15b
#

%ifnarch x86_64
%patch800 -p1 
%patch801 -p1
%patch802 -p1
#
# Make "top" more efficient
#
#
# rmap15c update
# 
%patch803 -p1
#
# some tweaks
#

%endif


%ifarch %{nptlarchs}
# O(1) scheduler
# threading backport:
%patch11000 -p1
%patch11001 -p1
# %patch11002 -p1
# %patch11003 -p1
%patch804 -p1
%patch11010 -p1
%else
%patch11030 -p1
%endif

# x86-64.. when done needs to move to the right place
# %patch220 -p1
# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/
chmod +x arch/sparc*/kernel/check_asm.sh

mkdir configs
%ifarch %{all_x86} x86_64
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-athlon*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config configs
%else
%ifarch sparc sparc64
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-sparc*.config configs
%else
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-%{_target_cpu}*.config configs
%endif
%endif

# make sure the kernel has the sublevel we know it has...
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

chmod 755 arch/*/kernel/check_asm.sh

###
### build
###
%build

# if RPM_BUILD_NCPUS unset, set it
if [ -z "$RPM_BUILD_NCPUS" ] ; then
    RPM_BUILD_NCPUS=`egrep -c "^cpu[0-9]+" /proc/stat || :` 
    if [ $RPM_BUILD_NCPUS -eq 0 ] ; then
	RPM_BUILD_NCPUS=1
    fi
    if [ $RPM_BUILD_NCPUS -gt 8 ] ; then
	RPM_BUILD_NCPUS=8
    fi
fi


cd linux-%{version}

cat > genkey <<EOF
%pubring `pwd`/kernel.pub
%secring `pwd`/kernel.sec
Key-Type: DSA
Key-Length: 512
Name-Real: Red Hat, Inc.
Name-Comment: Kernel Module GPG key
%commit
EOF

AddPatches () {
    # $1 is BOOT/bigmem/debug/foo
    case "$1" in
    debug) patch -p1 < $RPM_SOURCE_DIR/linux-2.4.7-ikd.patch ;;
    esac
    # remove any backup files that were created
    find . -name "*.orig" -exec rm -fv {} \;
    find . -name "*~" -exec rm -fv {} \;
}

RemovePatches () {
    # $1 is BOOT/bigmem/debug/foo
    case "$1" in
    debug) patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.7-ikd.patch ;;
    esac
    # remove any backup files that were created
    find . -name "*.orig" -exec rm -fv {} \;
    find . -name "*~" -exec rm -fv {} \;
}

DependKernel() {
    # is this a special kernel we want to build?
    if [ -n "$2" ] ; then
	Config=$1-$2
	KernelVer=%{version}-%{release}$2
	echo MAKE DEPEND FOR $2 $1 KERNEL...
    else
	Config=$1%{dashtargetboard}
	KernelVer=%{version}-%{release}
	echo MAKE DEPEND FOR up $1 KERNEL...
    fi
    make -s mrproper
# We used to copy the config file to arch/.../defconfig, but for some time now
# the Configure script has been smart enough to override this with the
# config file found in configs/kernel-%{kversion}-${config}.config when it
# finds a valid /boot/kernel.h file.  As a result, making an RPM on a
# machine that has a valid kernel.h file will result in scripts/Configure
# overriding our config entries with whatever it thinks is appropriate
# (aka, if you try an i386 build on a machine with an i686 smp kernel.h file
# then you will get an i686 smp kernel in an i386 package).  So, instead we
# put our config file in .config, which is considered the ultimate source
# of default config information by make oldconfig.  Also, copy the config
# files out of the configs directory instead of the RPM_SOURCE_DIR.  It
# doesn't make any sense to put them in there and then not use them,
# especially when we could have a patch that modifies the config files
# as part of the bigmem patch set (or any other patch, it just makes
# us more flexible to use the configs from the configs directory).  Finally,
# since make mrproper wants to wipe out .config files, we move our mrproper
# up before we copy the config files around.
    cp configs/kernel-%{kversion}-$Config.config .config
    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$2/" Makefile
%ifarch sparc sparc64     
    make -s ARCH=$1 oldconfig_nonint
    make -s ARCH=$1 dep
    make -s ARCH=$1 include/linux/version.h 
%else
    # We do it twice, because make oldconfig tends to get stuff wrong.
    make -s oldconfig_nonint
    make -s oldconfig_nonint
    make -s -j $RPM_BUILD_NCPUS dep
    make -s include/linux/version.h 
%endif
}

BuildKernel() {
    if [ -n "$1" ] ; then
	Config=%{_target_cpu}-$1
	KernelVer=%{version}-%{release}$1
	DependKernel %{_target_cpu} $1
	echo BUILDING A KERNEL FOR $1 %{_target_cpu}...
    else
	Config=%{_target_cpu}%{dashtargetboard}
	KernelVer=%{version}-%{release}
	DependKernel %{_target_cpu}
	echo BUILDING THE NORMAL KERNEL for %{_target_cpu}...
    fi

%ifarch %{all_x86} x86_64
#    make -s -j $RPM_BUILD_NCPUS CFLAGS_KERNEL="-Wno-unused" bzImage 
      cd ../freeswan-%{freeswan_version}
      make -s -j $RPM_BUILD_NCPUS insert
      make -s -j $RPM_BUILD_NCPUS ocf
      make -s -j $RPM_BUILD_NCPUS confcheck
      make -s -j $RPM_BUILD_NCPUS kernel
      cd ../linux-%{version}

%else
    make -s -j $RPM_BUILD_NCPUS boot 
%endif
#    make -s -j $RPM_BUILD_NCPUS CFLAGS_KERNEL="-Wno-unused" modules || exit 1
    
    # first make sure we are not loosing any .ver files to make mrporper's
    # removal of zero sized files.
    find include/linux/modules -size 0 | while read file ; do \
	echo > $file
    done
    # Start installing stuff
    mkdir -p $RPM_BUILD_ROOT/boot
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 $RPM_SOURCE_DIR/module-info $RPM_BUILD_ROOT/boot/module-info-$KernelVer
    install -m 644 configs/kernel-%{kversion}-$Config.config $RPM_BUILD_ROOT/boot/config-$KernelVer
    mkdir -p $RPM_BUILD_ROOT/dev/shm
%ifarch %{all_x86}
   cp arch/i386/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
   cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%else
%ifarch x86_64
   cp arch/x86_64/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
   cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%else
%ifarch ia64
    gzip -cfv vmlinux > vmlinuz
    mkdir -p $RPM_BUILD_ROOT/boot/efi/redhat
    install -m 755 vmlinux $RPM_BUILD_ROOT/boot/efi/redhat/vmlinux-$KernelVer
    install -m 755 vmlinuz $RPM_BUILD_ROOT/boot/efi/redhat/vmlinuz-$KernelVer
    ln -s efi/vmlinux-$KernelVer $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
    ln -s efi/vmlinuz-$KernelVer $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
%else
    gzip -cfv vmlinux > vmlinuz
    install -m 644 vmlinuz $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
%endif
    install -m 755 vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%endif
%endif


    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

##   mark the modules executable
#    if [ "$1" != "BOOT" ] ; then
#    	find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.o" -type f  | xargs chmod u+x
#    fi
    
##  mark the vmlinux* non-executable to fool strip-to-file
    chmod a-x $RPM_BUILD_ROOT/boot/vmlinux*

#   now separate out the debug info from the modules/vmlinux
#   /usr/lib/rpm/find-debuginfo.sh %{_builddir}/%{?buildsubdir} || :

#   and compress the modules for space
#    if [ "$1" != "BOOT" ] ; then
#    	find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.o" -type f  | xargs gzip -9
#    fi

#   remove files that will be generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*
#   remove legacy pcmcia symlink that's no longer useful
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/pcmcia


}

SaveHeaders() {
    echo "SAVING HEADERS for $1 $2"
    # deal with the kernel headers that are version specific
    mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1
    install -m 644 include/linux/autoconf.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/autoconf.h
    install -m 644 include/linux/version.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/version.h
    mv include/linux/modules \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/
    echo $2 $1 ../../savedheaders/$2/$1/ >> $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/list
}

###
# DO it...
###

rm -rf $RPM_BUILD_ROOT

%if %{buildjensen}
BuildKernel jensen
%endif

%if %{buildbigmem}
BuildKernel bigmem
SaveHeaders bigmem %{_target_cpu}
%endif

%if %{buildsmp}
BuildKernel smp
SaveHeaders smp %{_target_cpu}
%endif

%if %{buildBOOT}
BuildKernel BOOT
SaveHeaders BOOT %{_target_cpu}
%endif

%ifarch i386
DependKernel i586
SaveHeaders up i586
DependKernel i686
SaveHeaders up i686
DependKernel athlon
SaveHeaders up athlon
%endif
%ifarch sparc
DependKernel sparc64
SaveHeaders up sparc64
%endif

%ifarch i386 
DependKernel i586 smp
SaveHeaders smp i586
DependKernel i686 smp
SaveHeaders smp i686
DependKernel i686 bigmem
SaveHeaders bigmem i686
DependKernel athlon smp
SaveHeaders smp athlon
%endif
%ifarch sparc
DependKernel sparc64 smp
SaveHeaders smp sparc64
%endif

# UNIPROCESSOR KERNEL
%if %{buildup}
BuildKernel
%ifarch i386 alpha sparc ia64
SaveHeaders up %{_target_cpu}
%endif
%endif



###
### install
###

%install

cd linux-%{version}
mkdir -p $RPM_BUILD_ROOT/{boot,sbin}

#for i in $RPM_BUILD_ROOT/lib/modules/*; do
 # rm -f $i/build 
  #ln -sf ../../../usr/src/linux-%{KVERREL} $i/build
#done

%ifarch athlon i586 i686 sparc64
# these don't need much
rm -rf $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders
exit 0
%endif

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
rm -f drivers/net/hamradio/soundmodem/gentbl scripts/mkdep
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
ln -sf linux-%{KVERREL} $RPM_BUILD_ROOT/usr/src/linux
install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

#clean up the destination
#make -s mrproper -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
#cp configs/kernel-%{kversion}-%{_target_cpu}%{dashtargetboard}.config $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/.config
#make -s oldconfig_nonint -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
#make -s symlinks -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
#make -s include/linux/version.h -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

#this generates modversions info which we want to include and we may as
#well include the depends stuff as well, after we fix the paths
#make -s depend -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
find $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL} -name ".*depend" | \
while read file ; do
    mv $file $file.old
    sed -e "s|[^ ]*\(/usr/src/linux\)|\1|g" < $file.old > $file
    rm -f $file.old
done

# Try to put some smarter autoconf.h and version.h files in place
pushd $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/include/linux ; {
rm -rf modules modversions.h autoconf.h version.h
cat > modversions.h <<EOF
#ifndef _LINUX_MODVERSIONS_H
#define _LINUX_MODVERSIONS_H
#include <linux/rhconfig.h>
#include <linux/modsetver.h>
EOF
echo '#include <linux/rhconfig.h>' > autoconf.h
list=`find ../../savedheaders/* -name '*.ver' -exec basename '{}' \; | sort`
mkdir modules
for l in $list; do
    sed 's,$,modules/'$l, ../../savedheaders/list | awk -f %{SOURCE17} > modules/$l
    touch -r modules/$l modules/`basename $l .ver`.stamp
    echo '#include <linux/modules/'$l'>' >> modversions.h
done
echo '#endif' >> modversions.h
sed 's,$,autoconf.h,' ../../savedheaders/list | awk -f %{SOURCE16} >> autoconf.h
install -m 644 %{SOURCE15} rhconfig.h
echo "#include <linux/rhconfig.h>" >> version.h
keyword=if
for i in smp BOOT BOOTsmp bigmem  up ; do
# When we build in an i386, we don't have an bigmem header directory
# in savedheaders/i386/bigmem.  We also don't have a BOOT directory
# anywhere except in savedheaders/i386.  So, we need to use this method
# of determining if a kernel version string needs to be included in the
# version.h file
    verh=`echo ../../savedheaders/*/$i/version.h | awk ' { print $1 } '`
    if [ -n "$verh" -a -f "$verh" ]; then
	if [ "$i" = up ]; then
	    if [ "$keyword" = if ]; then
		echo "#if 0" >> version.h
	    fi
  	    echo "#else" >> version.h
	else
	    echo "#$keyword defined(__module__$i)" >> version.h
	    keyword=elif
	fi
	grep UTS_RELEASE $verh >> version.h
    fi
done
echo "#endif" >> version.h
if [ -f ../../savedheaders/%{_target_cpu}/up/version.h ] ; then
    # keep to a standard normally
    HEADER_FILE=../../savedheaders/%{_target_cpu}/up/version.h
else
    # test build not including uniprocessor, must get info from somewhere
    HEADER_FILE=$(ls ../../savedheaders/%{_target_cpu}/*/version.h | head -1)
fi
grep -v UTS_RELEASE $HEADER_FILE >> version.h
rm -rf ../../savedheaders
} ; popd
touch $RPM_BUILD_ROOT/boot/kernel.h-%{kversion}

rm -f $RPM_BUILD_ROOT/usr/include/linux

for i in $RPM_BUILD_ROOT/lib/modules/*; do
  rm -f $i/modules.*
done

rm -rf $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders
###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre bigmem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
cd /boot
%ifnarch ia64 
ln -sf vmlinuz-%{KVERREL} vmlinuz
%endif
ln -sf System.map-%{KVERREL} System.map
ln -sf module-info-%{KVERREL} module-info
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
fi


%post smp
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
fi

%post bigmem
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}bigmem
fi

%post jensen
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}jensen
fi

%ifnarch ia64
%post BOOT
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}BOOT
fi

%endif

# Allow clean removal of modules directory
%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
#rm -f /lib/modules/%{KVERREL}/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}
fi


%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}smp/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp
fi


%preun bigmem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}bigmem/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}bigmem
fi


%preun BOOT
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
#rm -f /lib/modules/%{KVERREL}BOOT/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}BOOT
fi


%preun jensen
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
#rm -f /lib/modules/%{KVERREL}jensen/modules.*


# We need this here because we don't prereq kudzu; it could be
# installed after the kernel
%triggerin -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin smp -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin bigmem -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin BOOT -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin jensen -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :


# Old kernel-headers packages owned include symlinks; new
# ones just make them so that we can have multiple kernel-headers
# packages installed.

%triggerpostun source -- kernel-headers < 2.2.16
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}
exit 0

%post source
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}

%postun source
if [ -L /usr/src/%{kslnk} ]; then 
    if [ -L /usr/src/%{kslnk} -a `ls -ld /usr/src/%{kslnk} 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/%{kslnk}
    fi
fi
exit 0

###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/boot/%{kernel_glob}
%ifarch ia64
/boot/efi/redhat/%{kernel_glob}
%endif
/boot/module-info-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}
%endif

%if %{buildsmp}
%ifnarch i386
%files smp
%defattr(-,root,root)
/boot/%{kernel_glob}smp
%ifarch ia64
/boot/efi/redhat/%{kernel_glob}smp
%endif
/boot/module-info-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}smp

%endif
%endif

%if %{buildbigmem}
%files bigmem
%defattr(-,root,root)
/boot/%{kernel_glob}bigmem
/boot/module-info-%{KVERREL}bigmem
/boot/System.map-%{KVERREL}bigmem
/boot/config-%{KVERREL}bigmem
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}bigmem
%endif

%if %{buildBOOT}
%files BOOT
%defattr(-,root,root)
/boot/%{kernel_glob}BOOT
/boot/System.map-%{KVERREL}BOOT
/boot/config-%{KVERREL}BOOT
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}BOOT
%endif

%ifnarch i586 i686 sparc64 athlon
# START BASE ARCHES ONLY
%ifarch i386 alpha sparc ia64 x86_64

%files source
%defattr(-,root,root)
%dir /usr/src/linux-%{KVERREL}
/usr/src/linux-%{KVERREL}/COPYING*
/usr/src/linux-%{KVERREL}/CREDITS
/usr/src/linux-%{KVERREL}/Documentation
/usr/src/linux-%{KVERREL}/MAINTAINERS
/usr/src/linux-%{KVERREL}/Makefile
/usr/src/linux-%{KVERREL}/README
/usr/src/linux-%{KVERREL}/REPORTING-BUGS
/usr/src/linux-%{KVERREL}/Rules.make
/usr/src/linux-%{KVERREL}/arch
%ifarch sparc
/usr/src/linux-%{KVERREL}/arch/sparc64
%endif
/usr/src/linux-%{KVERREL}/drivers
/usr/src/linux-%{KVERREL}/crypto
/usr/src/linux-%{KVERREL}/fs
/usr/src/linux-%{KVERREL}/init
/usr/src/linux-%{KVERREL}/ipc
/usr/src/linux-%{KVERREL}/kernel
/usr/src/linux-%{KVERREL}/lib
/usr/src/linux-%{KVERREL}/mm
/usr/src/linux-%{KVERREL}/net
/usr/src/linux-%{KVERREL}/scripts
%ifarch %{all_x86}
%{?ibcs_1:/usr/src/linux-%{KVERREL}/abi}
%endif
/usr/src/linux-%{KVERREL}/configs
/usr/src/linux-%{KVERREL}/include
/usr/src/linux-%{KVERREL}/include/asm
%ifarch %{all_x86}
%{?ibcs_1:/usr/src/linux-%{KVERREL}/include/abi}
%endif
/usr/src/linux-%{KVERREL}/include/linux
/usr/src/linux-%{KVERREL}/include/rxrpc
/usr/src/linux-%{KVERREL}/include/net
/usr/src/linux-%{KVERREL}/include/pcmcia
/usr/src/linux-%{KVERREL}/include/scsi
/usr/src/linux-%{KVERREL}/include/video
/usr/src/linux-%{KVERREL}/tmp_include_depends
%dir /usr/src/linux-%{KVERREL}/include
%dir /usr/src/linux-%{KVERREL}/arch
%ifarch alpha sparc
/usr/src/linux-%{KVERREL}/include/math-emu
%endif  

%files doc
%defattr(-,root,root)
%doc linux-%{version}/Documentation/*


%endif
# END BASE ARCHES ONLY
%endif


#
# Dear Mr. or Mrs. Journalist,
#
# The changelog below is a list of modifications that have been made
# to the kernel at one time. By no means does this text reflect any
# official position of Red Hat, Inc. nor does any text reflect what
# is in the actual current kernel, due to the fact that we actually log 
# tests and one-off builds as well.
#
# Sincerely yours,
#     Arjan van de Ven
#     Red Hat Linux kernel maintainer. 
#

%changelog
* Thu Apr 10 2003 Ralf Spenneberg <ralf@spenneberg.com>
- Added the following VPN-patches
-    FreeS/wan-%{freeswan_version}
-    x509-%{x509_version} for FreeS/wan
-    MPPE for PPTP Encryption

* Thu Feb 27 2003 Arjan van de Ven <arjanv@redhat.com>
- fix rmap<->DRM interaction (#85106)

* Tue Feb 25 2003 Arjan van de Ven <arjanv@redhat.com>
- resolve hang with ide-scsi (#85026)
- make cdrom devices honor O_EXCL

* Mon Feb 24 2003 Arjan van de Ven <arjanv@redhat.com>
- make USB not sleep with spinlocks
- merge ehci update
- merge DRM update
- fix SEGV signal hang (Roland)

* Sat Feb 22 2003 Arjan van de Ven <arjanv@redhat.com>
- fix oops on sys_swapoff(NULL)  -- Steve Dickson

* Fri Feb 21 2003 Arjan van de Ven <arjanv@redhat.com>
- disable the ACL patches, they break NFS
- update tg3 driver to latest
- fix DRM abi breakage vs XFree86 4.3


* Thu Feb 20 2003 Arjan van de Ven <arjanv@redhat.com>
- more VM work 
- more NPTL fixes (bugs found upstream)
- TUX bugfix (74445)

* Mon Feb 17 2003 Arjan van de Ven <arjanv@redhat.com>
- downgrade pwc webcam driver one notch to the last known working version
- work around vm livelock
- make the cciss driver not enable irq's in it's irq handler

* Thu Feb 13 2003 Benjamin LaHaise <bcrl@redhat.com>
- fix for shared statistic < 0

* Thu Feb 13 2003 Arjan van de Ven <arjanv@redhat.com>
- Signal fixes for LSB testsuite
- merge patch to fix init=/bin/sh
- 2.4.21-pre4-ac4 bugfixes (mostly IDE crashes)

* Mon Feb 09 2003 Arjan van de Ven <arjanv@redhat.com>
- merge 2.4.21-pre4-ac3 bugfixes 

* Tue Feb  4 2003 Stephen C. Tweedie <sct@redhat.com>
- Add ext3 fix for truncating negative i_blocks

* Mon Feb 03 2003 Benjamin LaHaise <bcrl@redhat.com>
- add oopsmeharder for debugging hard hangs

* Mon Feb 03 2003 Arjan van de Ven <arjanv@redhat.com>
- merge rmap15d
- set the sbp2 command buffer to 64 elements instead of 8

* Wed Jan 29 2003 Arjan van de Ven <arjanv@redhat.com>
- merge tcp stall fix from DaveM
- merge bugfixes from 2.4.21-pre4

* Mon Jan 13 2003 Steve Dickson <SteveD@RedHat.com>
- Merge in the ACL and XATTR patches from the UL and BestBits trees.

* Sat Jan 11 2003 Stephen C. Tweedie <sct@redhat.com>
- Merge in the LVM pvmove fix to current tree

* Wed Jan 8 2003 Benjamin LaHaise <bcrl@redhat.com>
- add AMD Golem fixup

* Fri Dec 20 2002 Michael K. Johnson <johnsonm@redhat.com> 2.4.20-2.1
- ACPI config fixes

* Wed Dec 18 2002 Benjamin LaHaise <bcrl@redhat.com>
- build version 2.4.20-2

* Wed Dec 18 2002 Jeff Garzik <jgarzik@redhat.com>
- iscsi compile fix
- fix acpi depmod warning

* Tue Dec 17 2002 Benjamin LaHaise <bcrl@redhat.com>
- build version 2.4.20-1

* Tue Dec 17 2002 Benjamin LaHaise <bcrl@redhat.com>
- add oprofile fixes from graydon, reenable
- enable ACPI with updates from jgarzik

* Mon Dec 02 2002 Arjan van de ven <arjanv@redhat.com> 
- move to 2.4.20-ac1

* Tue Nov 26 2002 Arjan van de Ven <arjanv@redhat.com>
- more threading backport 
- move to 2.4.20-rc4-ac1

* Wed Nov 20 2002 Arjan van de Ven <arjanv@redhat.com>
- move to 2.4.20-rc2-ac1

* Mon Nov 18 2002 Arjan van de Ven <arjanv@redhat.com>
- DRM 4.3 from X CVS

* Tue Nov 12 2002 Stephen C. Tweedie <sct@redhat.com>
- Add swapoff entry-matching fix

* Mon Nov 11 2002 Ingo Molnar <mingo@redhat.com>
- full threading backport from 2.5.47:
-  TLS API changes
-  sys_clone() enhancements (CLONE_SETTLS, CLONE_SETTID, CLONE_CLEARTID,
   CLONE_DETACHED)
-  generic pidhash
-  sys_exit() speedups
-  vcache for generic futexes
-  generic, improved futexes
-  new, threading related ptrace features
-  latest thread signals stuff (atomic signals, shared signals, etc.)
-  exit/fork task cache
-  threaded coredumping support
-  new uid cache
-  oom fixes
-  /proc updates for threading
-  per-CPU GDT

* Fri Nov 8 2002 Arjan van de Ven <arjanv@redhat.com>
- added tytso@mit.edu's ext3 patchkit
- added the EDD backport from Matt Domsch
- Andi Kleen's module allocation patch

* Thu Nov 7 2002 Arjan van de Ven <arjanv@redhat.com>
- remove ACPI again because Intel is unwilling to take patches
- add O_DIRECT support for NFS

* Mon Nov 4 2002 Arjan van de Ven <arjanv@redhat.com>
- Merge ACPI from SuSE kernel RPM

* Fri Oct 18 2002 Arjan van de Ven <arjanv@redhat.com>
- O(1) VM

* Mon Aug 26 2002 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.20-pre4-ac1

* Tue Aug 13 2002 Arjan van de Ven <arjanv@redhat.com>
- added audigy driver bits

* Mon Aug 12 2002 Arjan van de Ven <arjanv@redhat.com>
- ACLs removed for now because of stability and correctness problem

* Sun Aug 11 2002 Arjan van de Ven <arjanv@redhat.com>
- remove a lot of NFS patches, some were broken it seems

* Fri Aug 09 2002 Benjamin LaHaise <bcrl@redhat.com>
- fix network bug setting nr_frags on memory allocation failure

* Thu Aug 08 2002 Pete Zaitcev <zaitcev@redhat.com>
- A fix for bug 56856, SDDR-31 media check.

* Thu Aug 08 2002 Arjan van de Ven <arjanv@redhat.com>
- update the ips driver 

* Fri Aug 02 2002 Arjan van de Ven <arjanv@redhat.com>
- added most of the NFS patchkit

* Fri Aug 02 2002 Pete Zaitcev <zaitcev@redhat.com>
- Update UML to -48 version,
  split Red Hat specific changes into a separate patch.

* Mon Jul 26 2002 Arjan van de Ven <arjanv@redhat.com>
- add USB device ID for a pegasus based card

* Mon Jul 22 2002 Pete Zaitcev <zaitcev@redhat.com>
- Workaround for broken HP keyboards for #55878, patch 1241.

* Mon Jul 22 2002 Arjan van de Ven <arjanv@redhat.com>
- more NAPI updates (davem@redhat.com)
- Allow the use of all 256 scsi devices (zaitcev@redhat.com)

* Sun Jul 21 2002 Arjan van de Ven <arjanv@redhat.com>
- updated NAPI patches [DaveM]

* Wed Jul 17 2002 Benjamin LaHaise <bcrl@redhat.com>
- shut up "svc: unknown version (0)" messages

* Thu Jul 11 2002 Benjamin LaHaise <bcrl@redhat.com>
- pageattr patch to fix the AGP cache attribute conflict problem

* Thu Jul 11 2002 Pete Zaitcev <zaitcev@redhat.com>
- Fix for duplicate SCSI IDs from <nahshon@actcom.co.il> (bug 55876, patch 705)

* Fri Jul 5 2002 Benjamin LaHaise <bcrl@redhat.com>
- update futex patch from Rusty

* Thu Jul 4 2002 Arjan van de Ven <arjanv@redhat.com>
- update lmsensors to version 2.6.3

* Fri Jun 21 2002 Stephen C. Tweedie <sct@redhat.com>
- Add ext3 extended attribute code

* Thu Jun 20 2002 Stephen C. Tweedie <sct@redhat.com>
- Update ext3 to ext3-cvs version.
- Add ext3 htree patch

* Mon Jun 17 2002 Arjan van de Ven <arjanv@redhat.com>
- add "nousb" kernel option
- O(1) scheduler update from Ingo

* Mon Jun 10 2002 Doug Ledford <dledford@redhat.com>
- added adaptec's new scsi driver aic79xx

* Fri Jun 6 2002 Arjan van de Ven <arjanv@redhat.com>
- added oprofile (oprofile.sourceforge.net)

* Wed Jun 5 2002 Benjamin LaHaise <bcrl@redhat.com>
- add Rusty's futex patch for improved userspace locking primatives.

* Wed Jun 5 2002 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.19pre10-ac1
- merged UML

* Wed May 29 2002 Doug Ledford <dledford@redhat.com>
- enable highmem io on selected SCSI controllers for debugging

* Fri May 24 2002 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.19pre8-ac5

* Thu May 23 2002 Doug Ledford <dledford@redhat.com>
- add the aic7xxx 6.2.8 driver patch
 
* Wed May 22 2002 Arjan van de Ven <arjanv@redhat.com>
- update ecc driver
- fix proc oops in hpt36x driver
- add pci id's to promise ide driver
- fix typo in qla2200 driver
- fix compile issue for wdt_pci compiled built in


* Tue May 21 2002 Benjamin LaHaise <bcrl@redhat.com>
- add nfs default [rw]size fix (patch 1391) for bugzilla #64921, 64984, 65069

* Thu May 16 2002 Benjamin LaHaise <bcrl@redhat.com>
- brown paper bag fix for linux-2.4.18-proc-stat.patch: 
  don't add 1000000000 to interrupt counts (#64825)

* Thu May 16 2002 Doug Ledford <dledford@redhat.com>
- disable the AIRONET4800_CS driver from the PCMCIA directory (bug #64959)
 
* Mon May 13 2002 Michael K. Johnson <johnsonm@redhat.com>
- add the dnotify notification cancelling patch
 
* Mon May 06 2002 Pete Zaitcev <zaitcev@redhat.com>
- Make s390x work with O(1)
- Add s390 partitioning patch which everyone agrees to let into mainstream
- Fix initrd on s390x ... again
- Let ctc to load with CONFIG_MODVERSIONS (EXPORT_SYMBOL_NOVERS in fsm.c)
- bump to 2.4.18-0.32
 
* Tue Apr 30 2002 Doug Ledford <dledford@redhat.com>
- add the feral qlogic driver and start using it in place of qlogicisp

* Fri Apr 26 2002 Benjamin LaHaise <bcrl@redhat.com>
- add linux-2.4.9-vsnprintf.patch
- add linux-2.4.18-proc-stat.patch

* Thu Apr 18 2002 Arjan van de Ven <arjanv@redhat.com>
- added SSE init fix from Doug

* Tue Apr 16 2002 Benjamin LaHaise <bcrl@redhat.com>
- add linux-2.4.18-slabinfo.patch
- add LGPL headers for libredhat-kernel

* Sun Apr 14 2002 Arjan van de Ven <arjanv@redhat.com>
- add fix to loop.c for nfs refcount "leak"
- fix wvlan_cs oops
- add orinoco_old_cs for cards that don't like the newer driver

* Fri Apr 12 2002 Benjamin LaHaise <bcrl@redhat.com>
- rename libredhat-kernel.so.1 to libredhat-kernel.so.1.0.1 to allow
  librt to dynamically link against the dummy version

* Fri Apr 12 2002 Stephen C. Tweedie <sct@redhat.com>
- Add patch for misc fixes to block device buffer handling.

* Tue Apr 11 2002 Arjan van de Ven <arjanv@redhat.com>
- documented spec a bit more
- added suspend/resume fix from 2.4.9-31 to avoid regression
- added watcom usb ID's

* Tue Apr 09 2002 Pete Zaitcev <zaitcev@redhat.com>
- Sanitizing moremounts. Arjan fixed 62740 there by concatenation of patches.

* Tue Apr 09 2002 Arjan van de Ven <arjanv@redhat.com>
- final serverworks/acard/promise IDE bits

* Mon Apr 08 2002 Arjan van de Ven <arjanv@redhat.com>
- sort "hpt366 doesn't boot" issues
- add promise IDE patch from upstream to fix hang

* Fri Apr 05 2002 Arjan van de Ven <arjanv@redhat.com>
- put fstat patch back in
- fix kksymoops

* Mon Apr 01 2002 Pete Zaitcev <zaitcev@redhat.com>
- ide-tape: un-regress 36628, fix 62267.
- Tentatively added USB serial fix 61820.

* Wed Mar 27 2002 Stephen C. Tweedie <sct@redhat.com>
- Add LVM atomic filesystem snapshots patch

* Wed Mar 27 2002 Arjan van de Ven <arjanv@redhat.com>
- some IDE updates from Andre Hedrick
- eepro100 PCI ID's
- updated module-info (harald)
- bugfixes from 2.4.18-pre4-ac2

* Tue Mar 26 2002 Benjamin LaHaise <bcrl@redhat.com>
- add aio 20020326
- correct aio library install path

* Tue Mar 26 2002 Arjan van de Ven <arjanv@redhat.com>
- update megaraid to 1.18a

* Mon Mar 25 2002 Benjamin LaHaise <bcrl@redhat.com>
- fix mmap for odd drivers / vsyscalls

* Mon Mar 25 2002 Arjan van de Ven <arjanv@redhat.com>
- update e100/e1000
- update tg3 driver
- new logo graphics
- update qla2200 driver
- added megarac driver (still needs a lot of work)
- update iscsi

* Fri Mar 22 2002 Arjan van de Ven <arjanv@redhat.com>
- update to have the fixes from 2.4.19-pre3-ac5

* Tue Mar 19 2002 Pete  Zaitcev <zaitcev@redhat.com>
- restored the "moreunnamed" patch, which conflicted with Al's cleanups.

* Tue Mar 19 2002 Arjan van de Ven <arjanv@redhat.com>
- add more accurate process accounting from later -ac

* Thu Mar 14 2002 Benjamin LaHaise <bcrl@redhat.com>
- make sym53c8xx_2 actually called sym53c8xx_2.o

* Fri Mar 08 2002 Benjamin LaHaise <bcrl@redhat.com>
- add fix for inode sync problem (linux-2.4.18-sync_one.patch)

* Mon Mar 04 2002 Arjan van de Ven <arjanv@redhat.com>
- 2.4.18-ac3
- removed some stale patches
- added compaq driver update
- added tigon3 driver

* Fri Mar  1 2002 Stephen C. Tweedie <sct@redhat.com>
- Add akpm's get_request fairness patch from 2.4.19-pre1

* Thu Feb 28 2002 Stephen C. Tweedie <sct@redhat.com>
- Add linux-2.4.17-lvm-fixes.patch for miscellaneous local LVM fixes and
  tweaks.

* Wed Feb 27 2002 Stephen C. Tweedie <sct@redhat.com>
- Add bugfixes from LVM-1.0.3

* Mon Feb 25 2002 Arjan van de Ven <arjanv@redhat.com>
- updated e1000 driver to the GPL compatible version

* Fri Feb 22 2002 Pete Zaitcev <zaitcev@redhat.com>
- Bug 35215 patch #1261

* Fri Feb 22 2002 Doug Ledford <dledford@redhat.com>
- Forward port the iorl changes that were made for the 2.4.9 kernel
- Added the changes for the aic7xxx_old driver related to the iorl work

* Thu Feb 21 2002 Stephen C. Tweedie <sct@redhat.com>
- Merge in mempool from 2.5 for LVM's use.

* Wed Feb 20 2002 Pete Zaitcev <zaitcev@redhat.com>
- s390x in ExclusiveArch

* Wed Feb 20 2002 Arjan van de Ven <arjanv@redhat.com>
- 2.4.18rc2

* Fri Feb 19 2002 David Woodhouse <dwmw2@redhat.com>
- update ARM patch
- ARM rmap

* Fri Feb 15 2002 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.18rc1
- update O(1) scheduler
- update rmap

* Thu Feb 14 2002 Stephen C. Tweedie <sct@redhat.com>
- Add LVM atomic move patch

* Sun Feb 10 2002 Arjan van de Ven <arjanv@redhat.com>
- 2.4.18pre9

* Fri Feb 08 2002 Pete Zaitcev <zaitcev@redhat.com>
- Workaround for broken ATEN hardware for #55878.

* Mon Feb 04 2002 Arjan van de Ven <arjanv@redhat.com>
- updated linux-abi patch
- made the bootup printk's less noisy by default
- merged 2.4.18pre8

* Sat Jan 26 2002 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.18pre7 and rmap12a

* Sun Jan 14 2002 Arjan van de Ven <arjanv@redhat.com>
- added DRM for XFree86 4.2.0
- made a "pinned list" for the rmap VM as to keep mlock()ed pages
  out of the way of the VM.

* Fri Jan 12 2002 Arjan van de Ven <arjanv@redhat.com>
- O(1) scheduler
- JFS 1.0.12 for evaluation

* Tue Dec 18 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added watchdog patch

* Wed Dec 12 2001 Pete Zaitcev <zaitcev@redhat.com>
- Keep fix for #55420, while postponed by Marcelo.

* Wed Dec 12 2001 Arjan van de Ven <arjanv@redhat.com>
- updated qla2200/2300 driver

* Tue Dec 11 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.17-pre8

* Fri Dec 07 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.17-pre5
- add 32 bit quota back
- add netfilter bridging patches

* Wed Dec 05 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.17-pre3
- aacraid update

* Fri Nov 30 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix kfree of static in sd.c:sd_init()

* Fri Nov 30 2001 David Woodhouse <dwmw2@redhat.com>
- update ARM kernel patch to 2.4.16-rmk1

* Thu Nov 29 2001 Philip Copeland <bryce@redhat.com>
- retired the previous ipvs patchs (5800,5810,5820)
  new single ipvs patch

* Thu Nov 29 2001 Arjan van de Ven <arjanv@redhat.com>
- disable ipvs
- add qla2200 driver

* Tue Nov 27 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.16
- tux update

* Fri Nov 23 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.15

* Fri Nov 16 2001 David Woodhouse <dwmw2@cambridge.redhat.com>
- Merge MIPS kernel support

* Thu Nov 15 2001 David Woodhouse <dwmw2@cambridge.redhat.com>
- Merge SH kernel support

* Wed Nov 14 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix for #36059 (ymfpci). This bug is pushed to Linus, but I wish
  this to be in our tree all the same, for the sake of erratas.

* Mon Nov 12 2001 David Woodhouse <dwmw2@cambridge.redhat.com>
- Merge ARM kernel support

* Sat Nov 03 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.13-ac7

* Sun Oct 28 2001 Pete Zaitcev <zaitcev@redhat.com>
- Added workaround for #54390, reads from dasd return trailing garbage.
- Not applying s390 specific ac14 parts anymore: all there already.

* Sun Oct 28 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.13-ac4

* Tue Oct 16 2001 Pete Zaitcev <zaitcev@redhat.com>
- Killed port-specific __cpu_raise_softirq on s390 and s390x (warning flood)
- Removed loopfix part from linux-2.4.9-s390-ac11.patch, now generic.

* Sat Oct 13 2001 Pete Zaitcev <zaitcev@redhat.com>
- usb-uhci bugfix from mainstream, until it reaches us down the line

* Wed Oct 10 2001 Pete Zaitcev <zaitcev@redhat.com>
- ide-tape fix for HP Colorado, #36628

* Mon Oct 8 2001 Arjan van de Ven <arjanv@redhat.com>
- New Broadcom 5700/5701 driver version
- ptrace patches

* Mon Oct 8 2001 Stephen Tweedie <sct@redhat.com>
- Fix ext3 directory readahead bug on empty (deleted) directories

* Sun Oct 7 2001 Arjan van de Ven <arjanv@redhat.com>
- merge 2.4.10-ac7 bugfixes
- make alpha compile again

* Fri Oct 5 2001 Stephen Tweedie <sct@redhat.com>
- Bring ext3 up to version 0.9.11

* Fri Oct 5 2001 Arjan van de Ven <arjanv@redhat.com>
- went back to old emu10k driver; the new one has too many problems
- added PPP over ATM patch

* Thu Oct 4 2001 Arjan van de Ven <arjanv@redhat.com>
- merged a few 2.4.9-ac18 bugfixes

* Wed Oct 3 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed hotplug driver to make system load not 1.00

* Mon Oct 1 2001 Arjan van de Ven <arjanv@redhat.com>
- update qla1280 driver

* Wed Sep 25 2001 Arjan van de Ven <arjanv@redhat.com>
- update Serverraid driver
- add quite a few MODULE_LICENSE() tags
- revert gendisk patch from -ac10
- add "tainted" patch from Keith Owens

* Mon Sep 23 2001 Arjan van de Ven <arjanv@redhat.com>
- updated ataraid to latest versions
- updated to block highmem patch version 15 
- updated hotplugpci patch

* Sun Sep 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Add Rik van Riels VM tuning patch

* Sun Sep 23 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- update s390 patches to 2.4.9ac14
- start s390x support
- add printk patch again

* Fri Sep 21 2001 Ingo Molnar <mingo@redhat.com>
- update TUX

* Fri Sep 21 2001 Arjan van de Ven <arjanv@redhat.com>
- added aic7xxx_old to the "highmem capable" devicelist

* Mon Sep 17 2001 Arjan van de Ven <arjanv@redhat.com>
- update Jens' block highmem patch
- add patch for 48bit IDE LBA 
- updated e100/e1000 drivers
- added sd maxsectors patch

* Sat Sep 15 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- put all Red Hat specific s390 patches in one file

* Thu Sep 13 2001 Arjan van de Ven <arjanv@redhat.com>
- make freevxfs autoload

* Mon Sep 10 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.9-ac10
- update linux-abi to upstream 2.4.9-0 version

* Thu Sep 06 2001 Arjan van de Ven <arjanv@redhat.com>
- fix oops in ia64 unwind (#52486)
- added /proc/unalignedinfo for ia64 (#42310) while
  disabling the evil printk's

* Wed Sep 05 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.9-ac7

* Fri Aug 31 2001 Michael K. Johnson <johnsonm@redhat.com>
- make quota messages look saner
- pci hotplug modular

* Tue Aug 28 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed oops on ieee1394 disconnect

* Mon Aug 27 2001 Arjan van de Ven <arjanv@redhat.com>
- add grubby to %post and %preun to automatically change grub.conf
- added patch to fix #50785 (cipe doesn't reload)
- minor updates from 2.4.9-ac1

* Mon Aug 27 2001 Stephen C. Tweedie <sct@redhat.com>
- Bring ext3 up to version 0.9.8: fixes an NFS oops, cleans up some
  printk log levels, updates error state on disk more rigorously and
  adds a "do_sync_supers" module parameter to allow the  sychronous
  superblock flush behaviour of ext3-0.9.6 to be restored on demand. 

* Sat Aug 25 2001 Ingo Molnar <mingo@redhat.com>
- fix the acenic driver bug that caused random kernel memory being
  sent out on the wire, on x86 systems with more than 4 GB RAM.

* Sat Aug 25 2001 Arjan van de Ven <arjanv@redhat.com>
- backout out the ewrk3 driver to the 2.4.2 version (#51961)
  as that one worked.
- disabled oom moderation
- added tulip_old driver (the 2.4.2/2.4.3 version) (#49966, #51622)
- added Doug's latest i810 driver (#49876)
- fixed USB device table (#51229)

* Fri Aug 24 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820 to v0.10

* Fri Aug 24 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix for 52229

* Fri Aug 23 2001 Arjan van de Ven <arjanv@redhat.com>
- updated e1000 driver (#52154)
- removed /sbin/installkernel from the kernel rpm (moved 
  to the initscripts rpm)
- created 'noathlon' DMI blacklist entry for MSI MS-6330 motherboards
- fixed tasklet bug reported by both Broadcom and Intel
- backout a segment reload optimisation, lkml has bad bugreports about it
- added aic7xxx config option patch (Doug)

* Fri Aug 23 2001 Stephen C. Tweedie <sct@redhat.com>
- added uptodate ext3 code from the ext3 abort-handle-branch
  to handle taking the filesystem offline/readonly on fatal error
  cleanly.

* Thu Aug 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added clear_page_tables lock patch

* Thu Aug 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added periodic shrink of icache (#52374)
- merged trivial VM tuning patch from 2.4.8-ac9
- added more reservation bouncebuffers 
  for highmem performance (#52340)
- updated e100 driver to latest version

* Wed Aug 22 2001 Arjan van de Ven <arjanv@redhat.com>
- merged S390 patches from bero
- removed dmi chunk (#51458)
- merged bugfixes from 2.4.8-ac9 
- * posixthreads tid!=pid patch
- * scsi tape bugfixes

* Tue Aug 21 2001 Arjan van de Ven <arjanv@redhat.com>
- add scsi hang fix and USB net hang fix from 2.4.8-ac8

* Mon Aug 20 2001 Michael K. Johnson <johnsonm@redhat.com>
- modification to e1000 driver at Intel's request (#49571)

* Mon Aug 20 2001 Arjan van de Ven <arjanv@redhat.com>
- added PCI ID's for KT133A chipset to AGP/DRM
- added S390 tape patch (bero)
- add missing Fritz PCMCIA driver (#50999)
- removed CONFIG_BLK_DEV_OFFBOARD (#52073) as it was bogus
- merged several DRM fixes from 2.4.7-ac7

* Sat Aug 18 2001 Arjan van de Ven <arjanv@redhat.com>
- fix oops in NFS code
- merged "DRM scribbles memory" patch from SuSE

* Fri Aug 17 2001 Arjan van de Ven <arjanv@redhat.com>
- fix critical bugfixes from 2.4.8-ac6:
-  * cpu flags are unsigned long, not int (64 bit issue)

* Thu Aug 16 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.9-vma_merge_full.patch vma merging patch that
  speeds up mozilla and gcc quite a bit

* Thu Aug 15 2001 Arjan van de Ven <arjanv@redhat.com>
- IKD included for the debug kernel
- add bcm5700 bugfixes (PCI access functions)
- upgraded wvlan_cs to not sleep with spinlocks helt (#51507)
- added "noathlon" bootflag (#50926)
- updated ia64 drm to upstream version, ifarch ia64 only

* Wed Aug 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- clean up filelists a bit, add all_x86

* Wed Aug 15 2001 Arjan van de Ven <arjanv@redhat.com>
- fix "cardbus has IRQ 0 and crashes" bug (#51706)
- update i810 driver to fix oopses (Doug)
- add patch from 2.4.7-ac5 to fix a thinko in the VM

* Wed Aug 15 2001 Pete Zaitcev <zaitcev@redhat.com>
- Patch that allows to change USB printer probing order (#50218)

* Tue Aug 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Made the USB keyboard patch not printk on every keypress
- added udelay(1) to the eepro100 driver
- merged bugfixes from 2.4.8-ac5
- added arch/ppc64 code, doesn't touch non-ppc

* Mon Aug 13 2001 Pete Zaitcev <zaitcev@redhat.com>
- Add fix for #51142 (Japanese USB keyboard).

* Mon Aug 13 2001 Stephen C. Tweedie <sct@redhat.com>
- Merge ext3-0.9.6

* Mon Aug 13 2001 Benjamin C.R. LaHaise <bcrl@redhat.com>
- updated linux-2.4.7-page_table_races.patch see bug #51652
- remove comments about set_page_dirty (it's actually okay)

* Mon Aug 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- Minor specfile cleanups

* Mon Aug 13 2001 Arjan van de Ven <arjanv@redhat.com>
- critical bugfixes from 2.4.8-ac2
- more eepro100 PCI ID's (notting)
- more aacraid PCI ID's (adaptec)
- add patch to fix parport console pinning lp module (#51387)
- added LDT bugfix (from 2.4.8-ac2) needed for glibc

* Sun Aug 12 2001 Arjan van de Ven <arjanv@redhat.com>
- S/390 updates (Florian)

* Fri Aug 10 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820.c to v0.6

* Fri Aug 10 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bigendian patch for ext3 (sct)
- fix resume on Dell Inspiron 8000 (#51407)
- fix oops in parport code (#51194)
- added bugfixes from 2.4.7-ac11, including fix for #49287
- Added MXT bugfix (IBM CRIT)
- removed fs/namei patch as it breaks too much

* Thu Aug 9 2001 Arjan van de Ven <arjanv@redhat.com>
- added patch from Broadcom to fix crash under high load (#51272, #51041) 
- merged bugfixes from 2.4.7-ac10; including switching to DRM4.1 from -ac10
- added Dell DMI entries for rebooting/suspend (#51269, #51202)
- added aacraid PCI ID's (#51246)
- synced S390 tree (bero)
- new iscsi drop from Cisco to comply with latest ietf standard

* Wed Aug 8 2001 Arjan van de Ven <arjanv@redhat.com>
- added ia64 TLB patch from Ben (#45204)
- added io elevator stall patch from Ben
- merge bugfixes from 2.4.7-ac9
- add IDE blacklist entries (#50775)

* Tue Aug 7 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.7-ac8
- increased SCSI timeout (#50853)
- updated hotplug PCI patch (#50856)
- updated cpqfc driver (Compaq CRIT)
- added vfat-nfs patch (#50820, #50822, #45525, #37031)

* Mon Aug 6 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.7-ac7
- updated bcm5820 driver
- updated linux-abi patch

* Fri Aug 3 2001 Arjan van de Ven <arjanv@redhat.com>
- Added DRI for XFree 4.1

* Thu Aug 2 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bug where inodes were cached WAAY too long (vm bug)
- Added ethtool support to several drivers (Dell)
- Updated bcm5820 driver

* Wed Aug 01 2001 Michael K. Johnson <johnsonm@redhat.com>
- ext3 no longer optional

* Wed Aug 1 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.7-ac3

* Tue Jul 31 2001 Arjan van de Ven <arjanv@redhat.com>
- Added DaveM's fix for the ethtool ioctl

* Wed Jul 25 2001 Guy Streeter <streeter@redhat.com>
- ppc build fixes
- mac and pSeries rpm and Makefile support

* Wed Jul 25 2001 Michael K. Johnson <johnsonm@redhat.com>
- update to cpqarray 2.4.5

* Tue Jul 24 2001 Michael K. Johnson <johnsonm@redhat.com>
- add spinlocks to cramfs decompression for SMP operation

* Tue Jul 24 2001 Ingo Molnar <mingo@redhat.com>
- fixed rare BUG in reclaim_page

* Mon Jul 23 2001 Michael K. Johnson <johnsonm@redhat.com>
- removed accidentally added and unneeded ia64 BOOT kernel

* Mon Jul 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820 driver to v0.5

* Mon Jul 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Update MXT patch
- Updated GDTH driver
- Made EXT3 a module again
- Fixed module oops dumps
- Fiddled with VM some more
- Updated BCM5820 driver

* Sat Jul 21 2001 Arjan van de Ven <arjanv@redhat.com>
- made oom killer less trigger-happy

* Fri Jul 20 2001 Stephen C. Tweedie <sct@redhat.com>
- Fix slab-poison oops in ext3 checkpoint cleanup code

* Fri Jul 20 2001 Arjan van de Ven <arjanv@redhat.com>
- made EXT3 nonmodular to allow for better debugging/oopstracing
- updated e1000 driver to new version from Intel

* Thu Jul 19 2001 Stephen C. Tweedie <sct@redhat.com>
- Merge in ext3-0.9.3

* Thu Jul 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.6-ac5
- updated cciss driver
- renabled tux
- added Florian's s390 patch

* Mon Jul 16 2001 Stephen C. Tweedie <sct@redhat.com>
- Added ext3 fix for block allocation race

* Fri Jul 13 2001 Philip Copeland <bryce@redhat.com>
- Removed extra show_stack() function on the end of the tux2 patch
  arch/alpha/kernel/traps.c +103 and +129

* Fri Jul 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added raid1 wait_event patch

* Thu Jul 12 2001 Arjan van de Ven <arjanv@redhat.com>
- added updated cpqfc driver

* Tue Jul 10 2001 Ingo Molnar <mingo@redhat.com>
- merge multipath patch

* Mon Jul 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- change from 8 to 32 available swap areas (~1k memory cost)

* Sun Jul 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Pete's patch to fix the IDE tape

* Sat Jul 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch to not allocate highmem bouncepages on non-highmem machines
- fixed ia64 boot

* Fri Jul 06 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated Broadcom bcm5700 driver

* Thu Jul 05 2001 Arjan van de Ven <arjanv@redhat.com>
- updated airo_cs driver

* Thu Jul 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- initrd_dir because ia64 uses /boot/efi

* Mon Jul 03 2001 Arjan van de Ven <arjanv@redhat.com>
- Update hpt/pdcraid support
- updated to 2.4.5-ac23

* Mon Jul 02 2001 Michael K. Johnson <johnsonm@redhat.com>
- Removed nested ifarch's from %build/%files by adding arch exclusions

* Thu Jun 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Add prefetch() support to ia64

* Wed Jun 27 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac19
- fixed O(N^2) algorithm in buffercache sync code

* Tue Jun 26 2001 Philip Copeland <bryce@redhat.com>
- updated IPVS

* Tue Jun 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch fom Jakub to fix sections

* Mon Jun 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch from marcelo@conectiva.com.br to show better swapinfo

* Sun Jun 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated HPT370 driver

* Fri Jun 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added HPT370 driver
- reverted xircom_cb to older version

* Fri Jun 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- a bit more RPM flexibility with more existence macros
- conditionalize tape and BOOTtape kernels

* Thu Jun 21 2001 Arjan van de Ven <arjanv@redhat.com>
- reverted borken ext3 bit
- 2.4.5-ac17
- added /proc/sys/kernel/cad_pid patch

* Wed Jun 20 2001 Arjan van de Ven <arjanv@redhat.com>
- renumbered all the patches for future expansion / better separation
- new hotplug patch
- MXT patch

* Wed Jun 20 2001 Michael K. Johnson <johnsonm@redhat.com>
- speed things up a bit more for test builds:
  o buildup define for choosing whether to build the uniprocessor kernel
  o builddevfsd define ditto for devfsd (devfs itself still off)

* Tue Jun 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.5-ac16

* Mon Jun 18 2001 Arjan van de Ven <arjanv@redhat.com>
- added updated pdcraid driver

* Sun Jun 17 2001 Arjan van de Ven <arjanv@redhat.com>
- added CONFIG_SMALL, will need more tweaks for the BOOT kernel still

* Sat Jun 16 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac15

* Fri Jun 15 2001 Arjan van de Ven <arjanv@redhat.com>
- moved to 2.4.5-ac14
- made i386 optimize for cpu=586
- disabled TUX for VM testing
- updated ext3


* Mon Jun 11 2001 Michael K. Johnson <johnsonm@redhat.com>
- killed some spec file cruft, made the spec file easier to maintain

* Sat Jun 09 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac12
- New aacraid driver

* Sat Jun 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- ieee1394 update

* Fri Jun  8 2001 Bill Nottingham <notting@redhat.com>
- add 0530 ia64 patch, make it apply, etc.

* Thu Jun 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Marcelo's swap patch
- added but disabled new DRM code

* Mon Jun  4 2001 Bill Nottingham <notting@redhat.com>
- add locking fix for usb-uhci from Pete Zaitcev to linux-2.4.3-usb.patch

* Tue May 29 2001 Pete Zaitcev <zaitcev@redhat.com>
- re-enable usb patches 263, 271. The latter is on its way out but
  we need it still.

* Tue May 29 2001 Bill Nottingham <notting@redhat.com>
- regen ia64 patch

* Tue May 29 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac3
- updated EXT3
- Added hotplug pci for test
- Added VM patch by Andrea

* Mon May 28 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.5-ac2

* Sat May 26 2001 Arjan van de Ven <arjanv@redhat.com>
- merge base to 2.4.5-ac1

* Fri May 25 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.4-ac17 (mostly null pointer fixes)
- New version of 3ware driver
- New version of symbios driver
- New version of FreeVxFS 
- Added ECC module
- merge base to 2.4.4-ac17

* Thu May 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Added rawio fix from Shinya Narahara
- New version of EXT3

* Thu May 24 2001 Michael K. Johnson <johnsonm@redhat.com>
- modprobe loop on preun as well

* Wed May 23 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.4-ac14

* Tue May 22 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fixes from 2.4.4-ac12 and ac13

* Mon May 21 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Jakub's ELF loader patch
- Added i82365 patch
- Updated TUX2 patch to 2.4.4 E4 level

*  Fri May 18 2001 Philip Copeland <bryce@redhat.com>
- added ext3 support for 2.4 (EXPERIMENTAL AND **NOT** FOR PRODUCTION)

*  Fri May 18 2001 Philip Copeland <bryce@redhat.com>
- Added in the pyrixs chipset fix for stable PCI DMA xfer
  so things like udma5 burst xfers across bus masters will
  work without locking up sx/lx 164 alpha's

* Fri May 18 2001 Arjan van de Ven <arjanv@redhat.com>
- bugfixes from 2.4.4-ac10

* Thu May 17 2001 Bill Nottingham <notting@redhat.com>
- add qla2x00 v4.28
- revert tlb-shootdown portion of -ac patch for ia64

* Thu May 17 2001 Arjan van de Ven <arjanv@redhat.com>
- compaq raid update now for all archs
- new e100 / e1000 / megaraid drivers


* Wed May 16 2001 Arjan van de Ven <arjanv@redhat.com>
- Fix Dell Poweredge 8450 patch

* Tue May 15 2001 Benjamin LaHaise <bcrl@redhat.com>
- replace reservation patch with vmfixes for a few vm deadlocks with highmem

* Tue May 15 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Dell Poweredge 8450 patch
- Disable weird fixup for intel 450nx chipset

* Mon May 14 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bugfixes from 2.4.4-ac9
- discourage IRQ 12 for yenta_socket

* Fri May 11 2001 Arjan van de Ven <arjanv@redhat.com>
- Made ECN default to off and enabled CONFIG_INET_ECN

* Fri May 11 2001 Philip Copeland <bryce@redhat.com>
- no need for %ifdef'ing ipvs anymore

* Thu May 10 2001 Bill Nottingham <notting@redhat.com>
- add update for uhci driver on ia64

* Thu May 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- disable reservation patch for now, not quite cooked yet.

* Thu May 10 2001 Benjamin LaHaise <bcrl@redhat.com>
- updated reservation patch.  should work now.

* Thu May 10 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Al Viro's audit patches
- More drives for the blacklist 
- removed finer-flush patch

* Thu May 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added CD-532E-A to the ide dma blacklist

* Wed May 09 2001 Benjamin LaHaise <bcrl@redhat.com>
- added memory reservation

* Wed May 09 2001 Bill Nottingham <notting@redhat.com>
- new ia64 patch (based on 2.4.4, so back a couple bits out)

* Wed May 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch for serialport on xircom cardbus
- Merged bugfixes from 2.4.4-ac6

* Tue May 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Add headers for athlon smp to merged symbol set
- Revert the dead swap patch from -ac12

* Tue May 08 2001 Bill Nottingham <notting@redhat.com>
- new smartarray stuff from Compaq (ia64-only ATM)

* Tue May 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Bugfixes from 2.4.4-ac4 and 2.4.4-ac5
- Updated 8139too
- Fixed 8x registration bug in eepro
- Update gdth driver
- added fix for brlocks

* Mon May 07 2001 Michael K. Johnson <johnsonm@redhat.com>
- added linux-2.4.3-r128-drm-do-wait-for-fifo.patch

* Fri May 04 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added Dell patch to be able to specify rebooting from boot cpu with "s" flag
- updated linux-2.4.3-ymfpci.patch to include niph patch from Pete Zaitcev
- updated linux-2.4.3-usb.patch to include dereg patch from Pete Zaitcev

* Fri May 4 2001 Benjamin LaHaise <bcrl@redhat.com>
- remove linux-2.4.3-smpcall-fix.patch

* Fri May 4 2001 Stephen C. Tweedie <sct@redhat.com>
- Fix race in smp_call_function

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- bump version number

* Thu May 3 2001 Philip Copeland <bryce@redhat.com>
- Added in submitted patch for the nautilus alpha system
  from Hyung Min SEO <HMSEO@sec.samsung.com>

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- allow urgent VM page allocation requests to be satisfied more
  easily

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- added significant speedup for scanning full swap maps

* Wed May 2 2001 Stephen C. Tweedie <sct@redhat.com>
- added trivial host-cpu sysrq-T debug output

* Wed May 2 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-page_table_races.patch vm fixups

* Wed May  2 2001 Bill Nottingham <notting@redhat.com>
- don't call tty_write_message on unaligned traps on ia64

* Wed May 2 2001 Arjan van de Ven <arjanv@redhat.com>
- Added irq-fault lockup patch 
- Merged 2.4.4-ac3 bugfixes:
  - USB acm
  - APM allow_ints option
  - Descriptortable corruption
  - DMFE driver skb alloc  
  - typo in IDE code
  - netfilter updates
  - core network updates
  - via workaraound 686a fix
  - Alpha fixes


* Wed May 2 2001 Philip Copeland <bryce@redhat.com>
- added in DaveM's ALI patch for the sparc, with luck it may
  even work for the alpha

* Tue May 1 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-smpcall-fix.patch to fix a rare deadlock

* Tue May 1 2001 Arjan van de Ven <arjanv@redhat.com>
- attempt DMA livelock fix

* Mon Apr 30 2001 Arjan van de Ven <arjanv@redhat.com>
- Add patch to revert the "schedule fork'd first" patch in
  mainstream tree. It makes broken userspace show up too much.
  Also causes performance problems in some normal cases.
- fix via audio pci_enable_device
- added sct's fix to the per-cpu-pages patch

* Sun Apr 29 2001 Arjan van de Ven <arjanv@redhat.com>
- Prevent negative inode-used counts (aviro)

* Sat Apr 28 2001 Arjan van de Ven <arjanv@redhat.com>
- added patch to avoid recursing in deadlocks in create_bounce

* Fri Apr 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-vmlockup.patch for testing

* Fri Apr 27 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bcrl's highmem patch
- Removed bcrl's highmem patch
- Added Al Viro's sync_one patch
- Added a patch to add the "apic" commandline option for
  some broken motherboards

* Thu Apr 26 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added linux-2.4.3-highmemthrottle.patch

* Thu Apr 26 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bug #37759
- updated ips (ServerRAID) to 4.72
- Added Al Viro's bufferrace patch

* Wed Apr 25 2001 Bill Nottingham <notting@redhat.com>
- add qla1280 cleanup patch

* Wed Apr 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged to ac14
- Added IPv6 patch (DaveM)

* Mon Apr 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Added IRIX NFS Patch
- Added Ingo's swap patch

* Sun Apr 22 2001 Pete Zaitcev <zaitcev@redhat.com>
- Added a patch to restore my khubd fix over that official one.
  I think the official fix is no good, while ours is tested.
- Applied patch 271 again (with duplicated pieces removed).
- Added a patch for iForce joystick (#37075).

* Sun Apr 22 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.3-ac12 (for the PDC oops and the DVD bugfixes)
- added "apm=allowints" kernel option for suspend problems,
  made this the default for IBM laptops

* Sat Apr 21 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.3-ac11

* Fri Apr 20 2001 Bill Nottingham <notting@redhat.com>
- revert CDROM changes from ac10

* Fri Apr 20 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed (hopefully) bouncebufferheads deadlock
- change reboot-behavior of Dell PE1300's

* Thu Apr 19 2001 Pete Zaitcev <zaitcev@redhat.com>
- fix for ymfpci buzzing (#29562).

* Thu Apr 19 2001 Philip Copeland <bryce@redhat.com>
- added in patch to fix a subtle 21143 autonegotiation problem
  The driver would claim to negotiate 100-FD, but would report
  late collisions and bad transmit throughput.

* Thu Apr 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- cleaned up spec file a bit

* Thu Apr 19 2001 Arjan van de Ven <arjanv@redhat.com>
- added fix for FTP exploit
- merged to -ac10

* Wed Apr 18 2001 Arjan van de Ven <arjanv@redhat.com>
- upgraded to 2.4.3-ac9

* Tue Apr 17 2001 Bill Nottingham <notting@redhat.com>
- update ia64 to 010405 & sync

* Tue Apr 17 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated to 2.4.3-ac7
- merged Pete Zaitcev's USB bugfix-patches

* Mon Apr 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added IDE corruption fix

* Sun Apr 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Update release to 2.4.2-2
- Clean up some cruft in spec file
- Relax ordering requirements: gawk used in postun
- Strengthen ordering requirements: now prereq correct initscripts
  for mkkerneldoth (read: "make kernel dot h")

* Sun Apr 08 2001 Doug Ledford <dledford@redhat.com>
- Fix some multipath issues (multipath-fixes-4)

* Sun Apr 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated Xircom not-a-Tulip driver

* Sat Apr 07 2001 Doug Ledford <dledford@redhat.com>
- Hopefully the final round of i810 audio fixes

* Sat Apr 07 2001 Benjamin LaHaise <bcrl@redhat.com>
- extracted linux-2.4.2-page_bitmap.patch from vmpoison
  and added to all builds.

* Sat Apr 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Hopefully fixed the /boot/kernel.h issue forever
- Silence a few more printk's to be syslog only

* Sat Apr  7 2001 Matt Wilson <msw@redhat.com>
- disable debugging
- 0.1.51

* Sat Apr  7 2001 Ingo Molnar <mingo@redhat.com>
- added swap fixes

* Sat Apr  7 2001 Ingo Molnar <mingo@redhat.com>
- ext2fs corruption fixes

* Fri Apr 06 2001 Bill Nottingham <notting@redhat.com>
- more ia64 csum tweaks

* Fri Apr 06 2001 Doug Ledford <dledford@redhat.com>
- fix the multipath code and re-enable

* Thu Apr 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- Conditionalize multipath, disabled for now

* Thu Apr 05 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bcrl's patch to fix SMP swap corruption

* Thu Apr 05 2001 Doug Ledford <dledford@redhat.com>
- fix i810 sound driver to work around broken artsd and a kernel bug

* Wed Apr 04 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fixes for corruption in buffer.c and scsi_merge

* Wed Apr 04 2001 Michael K. Johnson <johnsonm@redhat.com>
- conflict with old versions of mount and nfs-utils

* Tue Apr 03 2001 Arjan van de Ven <arjanv@redhat.com>
- added ohci patch

* Tue Apr 03 2001 Ingo Molnar <mingo@redhat.com>
- TUX-fixes patch, update to -X4 version.

* Fri Mar 30 2001 Bill Nottingham <notting@redhat.com>
- fix ia64 build

* Thu Mar 29 2001 Bill Nottingham <notting@redhat.com>
- add patch to fix machine checks on ia64 (<asit.k.mallick@intel.com>)

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-dma-livelock-fix

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-vmtruncate.patch

* Wed Mar 28 2001 Stephen C. Tweedie <sct@redhat.com>
- Added aggressive reclaim of orphaned swap (if vmbalance enabled)

* Wed Mar 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Alan's cardbus patch
- Added zaitcev's USB message throttling

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added BUG() if buffer unlocked in end_io call to vmpoison patch
- added linux-2.4.2-rqdebug.patch from sct.

* Wed Mar 28 2001 Ingo Molnar <mingo@redhat.com>
- another batch of multipath-fixes, separate patch so that
  we have an easy way back.

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- added BUG() if buffer unlocked in end_io call to vmpoison patch

* Tue Mar 27 2001 Stephen C. Tweedie <sct@redhat.com>
- fix debugging conflict with smbfs internal debugging

* Tue Mar 27 2001 Tim Waugh <twaugh@redhat.com>
- added linux-2.4.2-restorestate.patch: fix bug #31170

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- fix debugging bug with reclaim_page

* Tue Mar 27 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Alan's "blacklist KT7RAID for IDE DMA" patch

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- updated linux-2.4.2-no_profile.patch to correct patch
- updated linux-2.4.2-vmpoison.patch to fix a bug

* Mon Mar 26 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-find_page.patch: potential corruption fix
- added linux-2.4.2-no_profile.patch regain 6MB of memory on boot
- added linux-2.4.2-bootmem_oom.patch to panic on oom during boot
- updated linux-2.4.2-vmpoison.patch with more poison, removed
  linux-2.4.2-uptodate.patch
- added linux-2.4.2-i2oinit.patch from Arjan

* Mon Mar 26 2001 Bill Nottingham <notting@redhat.com>
- patch from David Mosberger to fix networking issues on ia64

* Mon Mar 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Mark OSB4 driver experimental
- Update TUX2
- merged zaitcev's OV511 fix
- disabled dma66 for all via IDE chipsets

* Sun Mar 25 2001 Benjamin LaHaise <bcrl@redhat.com>
- Added linux-2.4.2-uptodate.diff to BUG() out on page cache misuse;
  also includes a potential fix for the corruption problem.

* Sun Mar 25 2001 Ingo Molnar <mingo@redhat.com>
- Update the multipath-fixes patch to the much less
  radical C0 version, B1 was never meant to be committed,
  it was a Dell-only test-patch!

* Sat Mar 24 2001 Stephen C. Tweedie <sct@redhat.com>
- Added buffer_head highmem fix

* Fri Mar 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-aviro-buffer.c.patch
- updated linux-2.4.2-vmpoison.patch

* Fri Mar 23 2001 Doug Ledford <dledford@redhat.com>
- Update the multipath-fixes patch to the B1 version from Ingo

* Fri Mar 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged bugfixes from 2.4.2-ac23
  * isapnp fix
  * reiserfs corruption
  * sound lock_kernel thinkos
  * allow sleeping in C-A-D handlers
  * small PPP race


* Thu Mar 22 2001 Bill Nottingham <notting@redhat.com>
- merge in 010321 ia64 patch from David Mosberger
- don't apply vmpoison.patch on ia64 (it relies on per-cpu-pages)

* Thu Mar 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-req_finished_io.patch for req_finished_io
- updated vmpoison.patch to fix a kmap problem
- added linux-2.4.2-ip_conntrack.patch to fix a hash table
  size of 0 which results in an Oops on startup
- added linux-2.4.2-pmd_alloc_fix.patch
- added linux-2.4.2-bootmem.patch to fix an off by one error
  that results in memory overwrites

* Thu Mar 22 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch from DaveM to fix IPv6 tunnels.
- Merged tux V1
- Disabled the Serverworks UDMA support
- Added IBM's new ServerRAID driver. This one has survived lots of testing
    by IBM
- Added ptrace patch

* Wed Mar 21 2001 Philip Copeland <bryce@redhat.com>
- Updated config files to take account of two new config options
  CONFIG_IP_VS_DEBUG (n)
  CONFIG_IP_VS_TAB_BITS (16)
- Modified the 2.4.2-cipe.patch to acomodate the change of location
  of ipvs

* Wed Mar 21 2001 Philip Copeland <bryce@redhat.com>
- retired Patch275 and replaced it with 276 on the recomendation of
  Wensong which moves ipvs from 0.1.2 -> 0.2.4
  Structurally removes net/ipv4/netfilter/ip_vs and moves it to
  net/ipv4/ipvs

* Wed Mar 21 2001 Doug Ledford <dledford@redhat.com>
- fix memory leak in i810 sound driver
- update scsi-reset patch to correct some locking issues under heavy reset
  conditions (James Bottomley)

* Wed Mar 21 2001 Stephen C. Tweedie <sct@redhat.com>
- Added shared memory locking fix

* Wed Mar 21 2001 Arjan van de Ven <arjanv@redhat.com>
- silenced DRI debugging messages
- merged Ingo's patch for spinlocks around apic operations

* Wed Mar 21 2001 Doug Ledford <dledford@redhat.com>
- update i810 sound driver to solve artsd output problems
- added scsi_scan patch to make scanning of sparselun devices work again
- update old aic7xxx driver to possibly fix 7896 lockup problems
- updated new aic7xxx driver to version 6.1.7

* Tue Mar 20 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch for netgear fa31x boards powerstate
- Added patch to silence PS/2 code (no keyboard there if
  there is a USB keyboard)

* Mon Mar 19 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Zaitcev's patch for USB mice (#23670)


* Sun Mar 18 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fix for HPT370 UDMA problem

* Fri Mar 16 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added qlogicfc to the list of controllers with limited scsi request sizes

* Thu Mar 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- updated binfmt_misc patch to create directory

* Thu Mar 15 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-ac20-pmd_alloc.diff fix for PAE

* Thu Mar 15 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Al Viro's patch to fs/namei.c
- Added the BKL patch for truncate (2.4.2-ac)
- added VM poison

* Wed Mar 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Added 2.4.2-ac20 I2O patches
- Made PCI printk's KERN_INFO

* Thu Mar 13 2001 Stephen C. Tweedie <sct@redhat.com>
- merge in VM performance changes up to 2.4.2-ac18

* Tue Mar 13 2001 Arjan van de Ven <arjanv@redhat.com>
- fix bug 30513 (iostat vs promise IDE boards)
- TUX 2.4.2-S4
- merged md fixes

* Mon Mar 12 2001 Bill Nottingham <notting@redhat.com>
- run /usr/sbin/module_upgrade in a kudzu trigger as well

* Mon Mar 12 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.2-ac18:
  - reiserfs cleanup
  - zerocopy bugfixes
  - zerocopy nbd
  - smbfs fixes
  - cyrix III MTRR checks
  - vmalloc race fix
  - pcmcia resource fix
- merged TUX 2.4.2-P3
- new version of the xircom driver
- default limit of 64 sectors in a scsi request
- enabled slab poison
- fixed 28489

* Fri Mar 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added another request-size limiting patch for Qlogic sbus and BusLogic,
  may need to add more adapters to this patch over time

* Fri Mar 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added QLogic ISP request-size limiting patch
- Updated xircom_cb driver to newer version
- Potential workaround for Abit KT7ARAID board bugs in via-corruption patch

* Thu Mar 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added cipefix patch from David Miller

* Thu Mar 08 2001 Stephen C. Tweedie <sct@redhat.com>
- add current raw IO fixes

* Thu Mar 08 2001 Pete Zaitcev <zaitcev@redhat.com>
- Adding a fix for usb-uhci to work when SLAB is not aligned (poisoned).

* Thu Mar 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- now prereq modutils 2.4.2-5 for new binfmt_misc support

* Thu Mar 08 2001 Arjan van de Ven <arjanv@redhat.com>
- added Ingo's bouncebuffer patch
- added Tim Waughs parport fixes
- switched to Alan's cleaned up megaraid
- added zaitcev's patch to prevent LVM oops
- added Than Ngo's patch for pcmcia ISDN
- forward-ported 2.2.19pre1 via timerbug workaround
- added Al Viro's binfmt_misc

* Wed Mar 07 2001 Arjan van de Ven <arjanv@redhat.com>
- added epca patch and more USB scanner ID's from 2.4.2-ac13
- added the IDE dma blacklist

* Tue Mar 06 2001 Doug Ledford <dledford@redhat.com>
- heavily patched/modified version of the i810 audio driver

* Tue Mar 06 2001 Arjan van de Ven <arjanv@redhat.com>
- added pge patch for Cyrix 686 kernels from Arjan

* Tue Mar 06 2001 Michael K. Johnson <johnsonm@redhat.com>
- depmod -ae

* Tue Mar 06 2001 Arjan van de Ven <arjanv@redhat.com>
- 2 more patches from 2.4.2-ac11/12 (8139too and the pci resources API change )
- workaround for the tokenring init mess
- added patch to enable the second IDE channel on PDC20265's

* Tue Mar  6 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.2-i2o-blocksize.patch (Patch225) to fix i2o /proc/partitions
  entries

* Mon Mar 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- Turned off CONFIG_USB_MOUSE because the HID code handles all mice we know

* Mon Mar 05 2001 Arjan van de Ven <arjanv@redhat.com>
- Added the patch from DHinds to fix cardbus irqs
- enabled multicast routing, bridging and QOS
- merged patches 214 to 224 from 2.4.2-ac11


* Sun Mar 4 2001 Philip Copeland <bryce@redhat.com>
- Reverted the parport_device_id changes that are in ac3
  which prevent the kernel-sources-x.y.z.src.rpm from
  being recompiled

* Fri Mar 02 2001 Ingo Molnar <mingo@redhat.com>
- linux-2.4.2-nmi-lockup-workaround.patch temporarily defaults nmi watchdog off

* Fri Mar 02 2001 Philip Copeland <bryce@redhat.com>
- added linux-2.4.2-alpha-irongate.patch from Compaq

* Fri Mar 02 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Arjan's linux-2.4.2-via-corruption.patch to fix disk corruption
  problems widely reported on KT133 machines
- Stephen/Tim fixed linux-2.4.1-axboe-scsi-max-sec.patch fixing scsi performance

* Thu Mar 01 2001 Doug Ledford <dledford@redhat.com>
- Added the scsi-reset patch so that you can reset devices through their
  sg entry

* Thu Mar 01 2001 Arjan van de Ven <arjanv@redhat.com>
- updated reiserfs to latest version
- prevent raid from oopsing
- lockd patch
- added alternate airo_cs driver
- added zaitcev's USB alloc fix

* Wed Feb 28 2001 Michael K. Johnson <johnsonm@redhat.com>
- atp.c would not compile as a module, fixed

* Wed Feb 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Added extra Toshoboe PCI ID (29993)
- added "fix hang in parport" patch (twaugh)
- maestro3 DMA fix
- fixed 29908 (loopdevice oops)

* Tue Feb 27 2001 Matt Wilson <msw@redhat.com>
- added a patch to fix for non-atomic bit clear in eepro100 driver on alpha
  (linux-2.4.2-eepro100-alpha.patch)

* Tue Feb 27 2001 Arjan van de Ven <arjanv@redhat.com>
- updated ikd to 2.4.2
- added olympic driver fix
- make Alpha happy
- added opl3sa patch
- added netdevice setup patch
- added 3ware patch
- merged TUX version G9
 
* Mon Feb 26 2001 Doug Ledford <dledford@redhat.com>
- bug fix to the aic7xxx-5.2.3 driver
- Added Michael E. Brown <michael_e_brown@dell.com> patch to add an ioctl to
  the block device layer to allow accessing the last sectors in a block
  device that has an odd number of sectors (needed for EFI compliance)
- Added Ingo's multipath I/O support for the md raid layer

* Mon Feb 26 2001 Bill Nottingham <notting@redhat.com>
- fix a case where the ia64 clock can go backwards (from <steiner@sgi.com>)

* Mon Feb 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Added netdebug patch on DaveM's request
- Added support for the Epson 1240U usb scanner
- removed wavelan udelay patch (no longer needed for gcc 2.96-74)
- derace the waking of the usb storage thread
- merged to 2.4.2-ac3, bumped version to 0.1.15
- put in the new, experimental xircom_cb driver
- upgraded to tux 2.4.2-F8

* Fri Feb 23 2001 Michael K. Johnson <johnsonm@redhat.com>
- added preinstalls for smp and enterprise to modprobe loop like uniprocessor
- disabled 3c90x driver because it does not work correctly.

* Fri Feb 23 2001 Bill Nottingham <notting@redhat.com>
- just remove modules.* in %preun; catches anything new, and
  avoids errors if certain files aren't there

* Fri Feb 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated 3c59x driver to version 1.1.14 from Andrew Morton
- enabled Hewlett-Packard 8200e/8210e CD-Writer Plus
- enabled Advanced routing (#29087)

* Tue Feb 22 2001 Matt Wilson <msw@redhat.com>
- updated module-info to the copy from anaconda CVS

* Thu Feb 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added 3ware patch
- re-enabled 3ware again

* Thu Feb 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- added linux-2.4.1-flush_tlb_export.patch
- updated to e100 1.5.5

* Wed Feb 21 2001 Doug Ledford <dledford@redhat.com>
- update Justin Gibbs' aic7xxx driver to version 6.1.4

* Wed Feb 21 2001 Bill Nottingham <notting@redhat.com>
- export a couple more symbols on ia64
- increase default size of swiotlb on ia64

* Wed Feb 21 2001 Michael K. Johnson <johnsonm@redhat.com>
- disable 3ware driver on SMP until a bugfix is found
- updated to tux2-2.4.1-P5 to fix dcache bug

* Wed Feb 21 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged bugfixes from ac20:
  - non-PNP AWE32 fix
  - updates to various pcmcia network drivers
- Added "ideX=nodma" commandline option

* Tue Feb 20 2001 Arjan van de Ven <arjanv@redhat.com>
- Reordered several patches to the proper section
- Merged the following patches from ac17-18-19:
  - jgarzik's network driver cleanups
  - reiserfs tailpacking datacorruption
  - smbfs off-by-one fixes
  - USB 2.0, USB Hub device claim race, USB net recovery 
  - SO_SNDTIMEO bugs
- Fixed CIPE on SMP machines (#28386)
- new tulip driver
- new version of the Loop fixes (Al Viro)
- backed out vm-rebalance; be careful with ext2
  
* Mon Feb 19 2001 Bill Nottingham <notting@redhat.com>
- minor ia64 tweaks

* Mon Feb 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- removed duplicate ksyms exports for alpha
- added brokenmptable patch from Ingo
- Turned on CONFIG_USB_MOUSE and CONFIG_USB_KBD because they
  are needed after all with some hardware and the conflicts with 
  CONFIG_USB_HID are non-fatal.

* Mon Feb 19 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged tulip PNIC updates from 2.4.1-ac18
- removed extra DSCC4=m config option
- changed to the EUI64 format for IPv6
- enlarged printk buffer (#28288)
- upgraded to ac16, bump to 0.1.11

* Fri Feb 16 2001 Arjan van de Ven <arjanv@redhat.com>
- actually commited NFS patch
- updated intel e1000 to version 3.0.7
- reverted the kudzu change
- actually build the HP5300 module
- provisional WinChip patch
- made the 2.4 kernel conflict with isapnptools as that conflict
  breaks the actual PNP in the 2.4 kernel.


* Thu Feb 15 2001 Arjan van de Ven <arjanv@redhat.com>
- NFS memcmp bug
- changed requires kudzu >= 0.93 to conflicts kudzu <= 0.92
- made the kernel conflict with program too old according
  to Documentation/Changes

* Thu Feb 15 2001 Bill Nottingham <notting@redhat.com>
- change wvlan_cs Config.in description to something more appropriate

* Thu Feb 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- Turned off CONFIG_USB_MOUSE and CONFIG_USB_KBD because they
  conflict with using CONFIG_USB_HID (hotplug loads both...)
- build toshiba module

* Thu Feb 15 2001 Karsten Hopp <karsten@redhat.de>
- search for all LUNs on CR3500 shared SCSI controller

* Wed Feb 14 2001 Doug Ledford <dledford@redhat.com>
- Add Justin Gibbs' aic7xxx driver version 6.1.1 as aic7xxx_new

* Wed Feb 14 2001 Michael K. Johnson <johnsonm@redhat.com>
- added quiet patch so that autorun and magicdev don't mangle logs

* Wed Feb 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Made Cyrix CPU's work again
- Added ideprobe patch to avoid hotprobe lockups
- fixed tulip xircom phase 2
- ikd (kdb)
- remove *~ files (#18751)
- fix poll() on usb printers (#26909)
- fixed argument parsing for sym63c416 driver
- merged ac13 patch to prevent parport from corrupting the pci dev list
- fixed sbpcd (ac13)
- fixed usbhub (ac13, missing unlock_kernel)
- fixed vmalloc race (ac13)
- potential uhci slab interaction fix
- smbfs fixes (ac13)
- tmpfs nlink fix for perl (ac13)
- arcnet init fixes (ac13)


* Wed Feb 14 2001 Matt Wilson <msw@redhat.com>
- 0.1.8
- turn off tux

* Tue Feb 13 2001 Bill Nottingham <notting@redhat.com>
- fix typos in debugging patch

* Tue Feb 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- turned off CONFIG_BLK_DEV_ALI15X3 for alpha
- updated to tux2-2.4.1-L4, merge with debugging and highmem patches
- added %debugging macro for turning debugging on and off
- updated to scsi-max-sec-2

* Tue Feb 13 2001 Matt Wilson <msw@redhat.com>
- 0.1.6
- turned off CONFIG_NETFILTER and CONFIG_FILTER in i386 BOOT config
- modified linux-2.4.1-ia64-010131-2.diff to use the new PCI_ROUTING_TABLE
  structure in acpiconf.c

* Tue Feb 13 2001 Arjan van de Ven <arjanv@redhat.com>
- Made "realmode poweroff" a commandline option disabled by default.
  (believed to fix #26261, #26760, #24198, #23322)
- disabled netfilter and such in the -BOOT option
- made the kernel slab patch a config-option disabled for BOOT
- ServerRAID 4.50

* Tue Feb 13 2001 Matt Wilson <msw@redhat.com>
- 0.1.5
- regenerated linux-2.4.1-ia64-010131-2.diff so it will patch
- specify ARCH= when building the common sparc/sparc64 headers

* Mon Feb 12 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Jens Axboe's scsi-max-sec-1 as linux-2.4.1-axboe-scsi-max-sec.patch
- updated to new aacraid driver (depends on Jens's patch) plus Matt Domsch's fix
- added changeloop-fixes-2 from Al

* Mon Feb 12 2001 Arjan van de Ven <arjanv@redhat.com>
- upgraded to 2.4.1-ac10
- merged new e100/e1000 drivers

* Sat Feb 10 2001 Matt Wilson <msw@redhat.com>
- disable broken sparcaudio drivers on sun4[cdm]
- disable reiserfs on all sparc
- added linux-2.4.1ac8-nopci.patch to correct builds if not using CONFIG_PCI
- added linux-2.4.1ac8-zap_page_range.patch

* Fri Feb 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- updated to Al's latest loop fixes

* Fri Feb 9 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.1-ac8, changed version number to 0.1.1
- added Ingo's highmem patch
- added IRC netfilter addon for DCC over NAT
- new megaraid driver (1.14g)
- Fix for bug 26696 (compaq vs irq 13)

* Thu Feb  8 2001 Bill Nottingham <notting@redhat.com>
- sync up ia64 with David Mosberger's 20010131 patch
- add x86-compatibility ia64 bugfix patch from Don Dugger

* Thu Feb  8 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.1-i2o-lockup.patch for some bus/card combos

* Thu Feb  8 2001 Bill Nottingham <notting@redhat.com>
- don't buildprereq gcc-2.96-74 on ia64

* Thu Feb 8 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.1-ac6, changed version number
- new broadcom driver
- serverworks workaround

* Wed Feb 7 2001 Arjan van de Ven <arjanv@redhat.com>
- corruption fix
- merged xircom_tulip into real tulip
- require gcc 2.96-74 or later for building
- merged aic7xxx from HEAD
- added DAC960 version 2.4.10

* Wed Feb 07 2001 Michael K. Johnson <johnsonm@redhat.com>
- use module_upgrade from kudzu package, prerequire kudzu >= 0.93

* Wed Feb  7 2001 Doug Ledford <dledford@redhat.com>
- fix the aic7xxx_new-6.1.0 patch :-(
- fix the aic7xxx_new-6.1.0 patch again :-(

* Wed Feb  7 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.1-i2o.patch.  This registers i2o block devices in
  /proc/partitions and fixes some other i2o bugs.

* Tue Feb 06 2001 Michael K. Johnson <johnsonm@redhat.com>
- require modutils 2.4.2 or greater

* Tue Feb  6 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Update devfsd to 1.3.11, fixes some glibc 2.2 issues

* Tue Feb  6 2001 Doug Ledford <dledford@redhat.com>
- update the aic7xxx driver to 5.2.2
- move the new Adaptec aic7xxx driver to aic7xxx_new

* Tue Feb  6 2001 Matt Wilson <msw@redhat.com>
- add a buildjensen macro, set it to 0 (as jensen seems broken)

* Mon Feb  5 2001 Matt Wilson <msw@redhat.com>
- 0.99.23
- make jensen subpackage on alpha (again, yuck)

* Mon Feb  5 2001 Matt Wilson <msw@redhat.com>
- 0.99.22
- turn on enterprise kernel
- set CONFIG_FILTER and CONFIG_NETFILTER to off in i386 BOOT kernel

* Mon Feb  5 2001 Arjan van de Ven <arjanv@redhat.com>
- Groundwork for the 2.4.1-ac2 merge
- turned of ACPI
 

* Mon Feb 5 2001 Arjan van de Ven <arjanv@redhat.com>
- added Matrox G450 patch
- updated from 2.4.1-ac1 to 2.4.1-ac2

* Fri Feb  2 2001 Matt Wilson <msw@redhat.com>
- tweaked the alpha boot kernel to be a little smaller
- moved the alpha header patch to if %%tux
- turn off tux
- added linux-2.4.0-alpha-header-conflict.patch
  (no more NFS root installs)

* Fri Feb 2 2001 Arjan van de Ven <arjanv@redhat.com>
- Socket DoS fix from Alexey/DaveM

* Thu Feb  1 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Add missing /etc/modules.devfs to devfsd package

* Thu Feb 01 2001 Michael K. Johnson <johnsonm@redhat.com>
- cciss 2.4.2
- integrated tested loop patches from Al

* Wed Jan 31 2001 Doug Ledford <dledford@redhat.com>
- added a fix for a PIII security hole

* Wed Jan 31 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.1-zap_page_range_fix.patch

* Wed Jan 31 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux patch tux2-2.4.0-final-S9

* Wed Jan 31 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed3c575 driver load typo-bug (23820)
- fixed athlon build for tux
- added provisional ide-floppy patch
- silenced the ide-cs driver a bit (resource management conflict between IDE
  and PCMCIA subsystems)
- made ia64 almost build

* Wed Jan 31 2001 Bill Nottingham <notting@redhat.com>
- include include/pcmcia in kernel-source so pcmcia drivers can build 

* Tue Jan 30 2001 Michael K. Johnson <johnsonm@redhat.com>
- temporarily disabled Al's loopback patches while he fixes them

* Tue Jan 30 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed i82365 driver (bug 24804)
- added "athlon" architecture
- Phase 1 of ide-cs fix
- maestro3 patch from Zach Brown

* Mon Jan 29 2001 Doug Ledford <dledford@redhat.com>
- Updated aic7xxx driver to 6.1.0
- Corrected a bug in the rhconfig.h file we install
- Corrected a bug in the build process in the spec file

* Mon Jan 29 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux2 patch tux2-2.4.0-final-R9
- integrated Al's loopback device fixes
- since enterprise kernel has only highmem-64GB support, limit to >= PIII

* Sun Jan 28 2001 Michael K. Johnson <johnsonm@redhat.com>
- integrated Linus's shared memory swap patch
- integrated Andrey's 1.36 eepro100 driver
- integrated block scheduler fix from pre11
- updated to new tux2 patch, now modular

* Fri Jan 26 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Jens Axboe's loop patch (disabled, Al fixing it and changeloop both)

* Fri Jan 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed parport_cs unresolved symbol
- reverted new wvlan port, the old one _did_ work

* Fri Jan 26 2001 Doug Ledford <dledford@redhat.com>
- added the xmm patch to keep the system from touching non-existent mxcsr
  registers
- verified that the two linux-merge-*.awk scripts do indeed use the right
  symbol names so that they should work properly

* Thu Jan 25 2001 Bill Nottingham <notting@redhat.com>
- remove /lib/modules/<whatever>/modules.generic_string as well (#24991)

* Thu Jan 25 2001 Michael K. Johnson <johnsonm@redhat.com>
- integrated new tux2 patch
- require new mkinitrd for RAID modules

* Thu Jan 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Added parport_cs port from pcmcia-cs package
- backed out to ac10
- new wvlan port, this one is reported to work even

* Wed Jan 24 2001 Erik Troan <ewt@redhat.com>
- updated RAID_AUTORUN patch

* Wed Jan 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Fix for bug 24698 (incorrect "build" link)
- Updated to 2.4.0-ac11 (still pre9 based), bumped version to 0.99.11
- added patch to fix most warnings people will see
- changes wvlan.o to wvlan_cs.o

* Tue Jan 23 2001 Matt Wilson <msw@redhat.com>
- 2.4.0-0.99.10, ac10 base
- rebuild with modutils 2.4.2 in place

* Tue Jan 23 2001 Matt Wilson <msw@redhat.com>
- added RAID_AUTORUN ioctl to raid driver from Ingo
- fixed the autorun patch

* Tue Jan 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- IDE DMA by default enabled
- add lm_sensors built as modules
- enable reiserfs

* Tue Jan 23 2001 Arjan van de Ven <arjanv@redhat.com>
- blacklisted IBM deskstar disks for UDMA on hpt366 controllers (dwmw2)
- added RAID5 corruption fix from 2.4.1-pre10
- added fix for FD problem from 2.4.1-pre10
- added DAC960 fix from 2.4.1-pre10 (Jens Axboe's patch)
- added fix wrong __init in io-apic.c from 2.4.1-pre10
- removed broadcom driver temporarily

* Mon Jan 22 2001 Matt Wilson <msw@redhat.com>
- uncomment rm -rf $RPM_BUILD_ROOT from %clean
- modified the drivers/usb/uhci.c patch of the ia64 patch to patch against ac10
- resynced kernel-2.4.0-i386-BOOT.config with available options
- added linux-2.4.0-tgafb-unregister-framebuffer.patch to pass correct
  value into unregister_framebuffer
- updated kernel-2.4.0-ia64-smp.config and kernel-2.4.0-ia64.config for
  available options

* Mon Jan 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.0-sysctl.patch
- added linux-2.4.0-map_user_kiobuf-fix.patch

* Mon Jan 22 2001 Matt Wilson <msw@redhat.com>
- increased ramdisk size of kernel-BOOT from 4096 to 4608

* Mon Jan 22 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to ac10, which already contains the waitpid patch

* Mon Jan 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.0-waitpid.patch to fix init/contextd SIGCHLD race

* Mon Jan 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added first draft of wvlan driver
- touched the ide-cs thing. Please test

* Mon Jan 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- turned on e1000 driver again
- e100 updated to 1.5.0 as linux-2.4.0-e100.patch

* Mon Jan 22 2001 Erik Troan <ewt@redhat.com>
- switched ide-cd back to a module in all x86 kernels

* Fri Jan 19 2001 Arjan van de Ven <arjanv@redhat.com>
- added Broadcom 5700 driver
- added patch to workaround gross misuse of ASSERT in IrDA

* Fri Jan 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added aacraid driver (broken so added as a non-building placeholder)
- Turn off modules on Alpha that are not building correctly
- Turn off e100 driver on IA64 because it doesn't build there
- Added linux-2.4.0-ieee1394-queuefix.patch for task queue changes
- Added linux-2.4.0-3x90x.patch 3c90x driver from 3com

* Fri Jan 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated megaraid to 1.14b
- made the non-smp kernel provide "kernel = 2.4"
- made the smp kernels provide "module-info"

* Thu Jan 18 2001 Philip Copeland <bryce@redhat.com>
- added in the SARD patch

* Thu Jan 18 2001 Erik Troan <ewt@redhat.com>
- switched idefloppy to build in
- updated e100, e1000 driver
- enabled natsemi module in i386 BOOT kernel

* Thu Jan 18 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux patch
- turned on CONFIG_IP_NF_IRC as module

* Wed Jan 17 2001 Matt Wilson <msw@redhat.com>
- fixed typo in linux-2.4.0-aic7xxx-6.0.8BETA.patch for !i386 !alpha

* Wed Jan 17 2001 Bill Nottingham <notting@redhat.com>
- update to cipe-1.4.5, make it one patch

* Wed Jan 17 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.0-ac9

* Tue Jan 16 2001 Bill Nottingham <notting@redhat.com>
- fix the aic7xxx patches to not patch backup files
- fix the cipe makefile so that it builds

* Mon Jan 15 2001 Doug Ledford <dledford@redhat.com>
- move the current aic7xxx driver aic7xxx_old
- add Justin Gibbs' new aic7xxx driver
- add a fix so that the cs4281 module will build

* Fri Jan 12 2001 Karsten Hopp <karsten@redhat.de>
- added starfire mmio patch to allow reload of this module

* Fri Jan 12 2001 Philip Copeland <bryce@redhat.com>
- Added in hooks for the ipvs 0.1.2 production kits to ksyms.c
- Added in patch250 to the spec file referancing linux-2.4.0-ipvs.patch
- added subdir ipvs in kernel tree which holds ipvs module code
- ac4 typo fix

* Fri Jan 12 2001 Michael K. Johnson <johnsonm@redhat.com>
- made build symlink relative
- qla1x160src-3.23Beta as linux-2.4.0-qla1280.patch
- make oldconfig_nonint so that builds reliably fail when config files need mods

* Thu Jan 11 2001 Bill Nottingham <notting@redhat.com>
- turn off CONFIG_DISABLE_VHPT on ia64, it's broken
- fix cs4281 makefile oops
- add new patch to possibly fix broken CONFIG_DISABLE_VHPT

* Thu Jan 11 2001 Karsten Hopp <karsten@redhat.de>
- moved e1000-2.5.11.patch and the update to 2.5.14 into one patch

* Thu Jan 11 2001 Michael K. Johnson <johnsonm@redhat.com>
- Moved back to static IDE for now because a couple machines had problems.
- qla1x160src-3.22Beta as linux-2.4.0-qla1280.patch
- megaraid 1.13s as linux-2.4.0-megaraid.patch

* Wed Jan 10 2001 Matt Wilson <msw@redhat.com>
- add free_dma and request_dma prototype in asm-ia64/dma.h as
  Patch58: linux-2.4.0-ia64-free_dma.patch
- remove Patch54: linux-2.4.0-test11-ia64-ksyms.patch
- remove Patch55: linux-2.4.0-test12-ia64-idesym.patch

* Wed Jan 10 2001 Bill Nottingham <notting@redhat.com>
- sync ia64 (010109 patch)

* Wed Jan 10 2001 Matt Wilson <msw@redhat.com>
- merged alpha .config files back to the way they need to be
- turn alpha back on

* Wed Jan 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- update to 2.4.0-ac4
- pcmcia moved to its own package
- update to new tux patch
- e820 reporting from Arjan
- Andi's RAID5 xor fix
- Ingo's Athlon APIC fix

* Mon Jan  8 2001 Bill Nottingham <notting@redhat.com>
- remove ksymoops/kernel-utils

* Fri Dec 29 2000 Bill Nottingham <notting@redhat.com>
- fix up prereqs

* Wed Dec 27 2000 Bill Nottingham <notting@redhat.com>
- something is horribly, horribly wrong with modular SCSI on ia64; turn it off
- rename source RPM back to 'kernel'

* Fri Dec 22 2000 Erik Troan <ewt@redhat.com>
- updated pcmcia config file for 2.4 cardbus support

* Thu Dec 21 2000 Erik Troan <ewt@redhat.com>
- turned HOTPLUG on for i386 BOOT kernel (PCMCIA doesn't build w/o it)

* Tue Dec 19 2000 Michael K. Johnson <johnsonm@redhat.com>
- Added linux-2.4.0-test11-vidfail.patch and enabled it for the x86 BOOT kernel
- More USB support in x86 BOOT kernel
- Require new mkinitrd for IDE modules
- SCSI entirely modular

* Fri Dec 15 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix unresolved symbol on ia64 in ide-probe-mod

* Wed Dec 13 2000 Michael K. Johnson <johnsonm@redhat.com>
- CONFIG_PARPORT_PC_FIFO off, bad default at this time

* Tue Dec 12 2000 Matt Wilson <msw@redhat.com>
- switch to un-TUXified kernel
- turn on framebuffer in the BOOT kernel

* Tue Dec 12 2000 Michael K. Johnson <johnsonm@redhat.com>
- New RC of TUX-1.01 patch

* Fri Dec 08 2000 Michael K. Johnson <johnsonm@redhat.com>
- CONFIG_HAPPYMEAL turned on for all architectures

* Thu Dec  7 2000 Bill Nottingham <notting@redhat.com>
- update ia64 patch to the 1206 version
- update e100, e1000 drivers

* Wed Dec 06 2000 Michael K. Johnson <johnsonm@redhat.com>
- Require fileutils for ln use in %post scripts
- Modular IDE

* Tue Dec 05 2000 Michael K. Johnson <johnsonm@redhat.com>
- Remove apa1480 driver temporarily for TUX build

* Mon Dec  4 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix SWIOTLB from Asit Mallick

* Sun Dec  3 2000 Bill Nottingham <notting@redhat.com>
- turn on usb-uhci as well as uhci
- update megaraid to 1.13beta

* Thu Nov 30 2000 Michael K. Johnson <johnsonm@redhat.com>
- TUX 1.01 RC

* Wed Nov 29 2000 Bill Nottingham <notting@redhat.com>
- fix ia64 semaphore symbol problems
- fix cipe symbol problems

* Wed Nov 29 2000 Michael K. Johnson <johnsonm@redhat.com>
- TUX 1.01 integrated with test11

* Tue Nov 28 2000 Bill Nottingham <notting@redhat.com>
- make ia64 patch patch cleanly with test11

* Mon Nov 27 2000 Bill Nottingham <notting@redhat.com>
- remove all modules.<foo>map files on package removal

* Fri Nov 24 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix FAT32, patch for alignment of unwind data

* Mon Nov 20 2000 Bill Nottingham <notting@redhat.com>
- make nfs a module

* Thu Nov 16 2000 Bill Nottingham <notting@redhat.com>
- new ia64 patch from David Mosberger
- make ppp a module
- allow glibc to build for the moment

* Fri Nov 10 2000 Bill Nottingham <notting@redhat.com>
- fix alpha build

* Thu Nov  9 2000 Bill Nottingham <notting@redhat.com>
- add patch from Asit Mallick to fix ia64 VHPT disabling

* Wed Nov  8 2000 Bill Nottingham <notting@redhat.com>
- add ia64 module patch

* Wed Nov 08 2000 Erik Troan <ewt@redhat.com>
- updated to test10, builds on ix86

* Wed Nov  1 2000 Bill Nottingham <notting@redhat.com>
- build some stuff statically (bleah)

* Tue Oct 31 2000 Bill Nottingham <notting@redhat.com>
- new ia64 diff from David Mosberger

* Thu Oct 26 2000 Bill Nottingham <notting@redhat.com>
- turn off ptc.g, again (oops)

* Wed Oct 25 2000 Bill Nottingham <notting@redhat.com>
- EFI GUID partition support from Matt Domsch (Matt_Domsch@dell.com)

* Tue Oct 24 2000 Bill Nottingham <notting@redhat.com>
- qlogic 1x160 version 3.19beta
- qlogic 2x00 version 4.15beta
- e1000 v2.5.11
- e100 v1.3.14
- make netfilter build on ia64 (cringe)

* Mon Oct 23 2000 Bill Nottingham <notting@redhat.com>
- update to test9 final
- ia64 updates

* Fri Sep 29 2000 Bill Nottingham <notting@redhat.com>
- clean up requirements (kill devfsd, initscripts)

* Fri Sep 29 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-H8-nodebug

* Thu Sep 28 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-G9-nodebug

* Tue Sep 26 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-G4-nodebug and test9-pre7 kernel
- turned off qla2x00 because it does not know about new scsi init arch
- turned off cciss because of parse error

* Thu Sep 21 2000 Bill Nottingham <notting@redhat.com>
- revert the part of the ia64 patch that requires new modutils for now
- turn off e1000 on ix86/alpha configs

* Tue Sep 19 2000 Bill Nottingham <notting@redhat.com>
- merge in stuff from Matt Domsch
- upgrade ia64 patch from David Mosberger

* Tue Sep 19 2000 Matt_Domsch <Matt_Domsch@dell.com>
- kernel 2.4.0-0.28.4
- Upgraded acenic to v0.47

* Thu Sep 14 2000 Matt_Domsch <Matt_Domsch@dell.com>
- kernel 2.4.0-0.28.3
- Removed I2O again
- Added ia64-000913 patch

- kernel-2.4.0-0.28.2
- removed kern0906.patch
- added 2.4.0-test8-000908 IA-64 patch
- added 2.4.0-test8-ia64 irqfix patch (fixes bigsur infinite IRQ0s)
- enable i2o
- added ia64_iobase export to arch/ia64/kernel/ia64_ksyms.c

* Tue Sep 12 2000 Michael K. Johnson <johnsonm@redhat.com>
- qla2x00 driver rev 4.10
- moved some things from modules to static builds
- sym53c8xx 64-bit patch

* Tue Sep 12 2000 Bill Nottingham <notting@redhat.com>
- make iso9660 & eepro100 static for now
- new ia64 patches from David Mosberger

* Fri Sep  8 2000 Bill Nottingham <notting@redhat.com>
- make nfs & lockd static on ia64; bad things happen otherwise
- update to test8 (turn off sisfb, it doesn't build)

* Thu Sep  7 2000 Bill Nottingham <notting@redhat.com>
- big piles of ia64 updates
- add in e1000 driver, fix modular build
- update acenic to 0.46 for the non-tux case
- update megaraid to 1.10c
- update qla1280 to 3.16b
- build against test7-final (not test8-pre1) for now

* Tue Sep  5 2000 Florian La Roche <Florian.LaRoche@redhat.com>
- update to pcmcia-cs 3.1.20
- remove obsolete pcmcia-cs-3.1.3-3com.patch

* Thu Aug 31 2000 Michael K. Johnson <johnsonm@redhat.com>
- More work on TUX: new version, better integration, still incomplete
- updated to 2.4.0-test8-pre1
- temporarily disabled matrox maven driver because of ICE

* Thu Aug 24 2000 Michael K. Johnson <johnsonm@redhat.com>
- Added TUX (but currently commented out because of insufficient generality)
- Config files mention tux so that the SRPM will still build if you add
  the patch.  However, they will not build TUX in without changes.

* Wed Aug 16 2000 Michael K. Johnson <johnsonm@redhat.com>
- dropped pcmcia-cs copy -f fix in from 2.2

* Tue Aug 15 2000 Bill Nottingham <notting@redhat.com>
- update ia64 stuff

* Tue Aug 15 2000 Jakub Jelinek <jakub@redhat.com>
- update to test7-pre4
- fix emu10k1 build on alpha
- .config updates

* Mon Aug 14 2000 Jakub Jelinek <jakub@redhat.com>
- fix linux-merge-config.awk
- remove /usr/include/{linux,asm*} in kernel-headers %pre

* Thu Aug 10 2000 Bill Nottingham <notting@redhat.com>
- update to test6-final (vger patch is merged)

* Wed Aug  9 2000 Jakub Jelinek <jakub@redhat.com>
- update to test6/pre9
- apply vger patches
- make it build on sparc32

* Tue Aug  8 2000 Bill Nottingham <notting@redhat.com>
- make it build on ia64

* Tue Aug  8 2000 Jakub Jelinek <jakub@redhat.com>
- /usr/include/{linux,asm} are directories
- fix header merging
- update to test6/pre8

* Wed Aug  2 2000 Bill Nottingham <notting@redhat.com>
- add ia32 signal patch for ia64

* Tue Aug  1 2000 Bill Nottingham <notting@redhat.com>
- update to pre5/ia64-728 (argh)
- update qla2x00 scsi driver to 4.0 (from Qlogic)

* Wed Jul 26 2000 Bill Nottingham <notting@redhat.com>
- clean up the %posts some

* Wed Jul 26 2000 Jakub Jelinek <jakub@redhat.com>
- Rename kernel24 subpackages back
- parport fix from Tim Waugh
- make it build on Alpha (hopefully)

* Wed Jul 26 2000 Jakub Jelinek <jakub@redhat.com>
- kill some of the ugly hacks, replace them with other ugly
  hacks so that the package can be built as the main distribution
  kernel or an experimental one.
- fix the export memcpy/memset patch
- add enterprise kernel (64GB kernel) on i686

* Tue Jul 25 2000 Bill Nottingham <notting@redhat.com>
- ugly hacks to get just the headers out

* Tue Jul 25 2000 Jakub Jelinek <jakub@redhat.com>
- kill several unresolved symbols from modules

* Fri Jul 21 2000 Bill Nottingham <notting@redhat.com>
- more tweaks

* Thu Jul 20 2000 Jakub Jelinek <jakub@redhat.com>
- some more tweaks

* Tue Jul 18 2000 Jakub Jelinek <jakub@redhat.com>
- CIPE
- a couple of patchlets
- FHS tweaks

* Wed Jun 21 2000 Bill Nottingham <notting@redhat.com>
- update acenic, megaraid, qla1280 drivers
- minor kernel header tweak for userland

* Sat Jun 17 2000 Bill Nottingham <notting@redhat.com>
- bump up ramdisk size on ia64 & alpha
- compile more stuff into the kernel until modules work better

* Fri Jun 16 2000 Bill Nottingham <notting@redhat.com>
- add ia32 signal handling patch for ia64

* Thu Jun 15 2000 Jakub Jelinek <jakub@redhat.com>
- reenable changeloop patch

* Wed Jun 14 2000 Bill Nottingham <notting@redhat.com>
- merge in loopback fixes from -ac series

* Tue Jun 13 2000 Bill Nottingham <notting@redhat.com>
- ia64 updates (0609 patch)
- module config/versioning updates

* Mon Jun  5 2000 Bill Nottingham <notting@redhat.com>
- merge in the ia64 stuff
- move to /dev/shm

* Sat Jun  3 2000 Jakub Jelinek <jakub@redhat.com>
- fix rhconfig.h (from Bero)

* Mon May 29 2000 Jakub Jelinek <jakub@redhat.com>
- 2.4.0-test1
- changeloop patch
- fix BuildASM
- fix compilation with gcc 2.96
- fix devfsd compilation

* Sat May  6 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- pre7-6
- devfsd 1.3.8
- add even more confusion to the versioning hell ;)
  (so we can deal with pre-pre versions)

* Fri Apr 28 2000 Bill Nottingham <notting@redhat.com>
- update for ia64
- pre6-final
- don't apply abi patch until it stops imploding on boot

* Mon Apr 17 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre6-pre3
- update ksymoops to 2.3.4
- update pcmcia to 3.1.14
- devfsd 1.3.4, devfs 162
- link ksymoops statically to get rid of the dependency on a particular
  version of binutils
- adapt abi patch to new kernel interfaces
- minor fixes to spec file

* Wed Mar 22 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre3-7
- remove some fixes (they're now in the base version)

* Tue Mar 21 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add /var/shm dir
- require initscripts >= 5.03 so we mount /var/shm
- 2.3.99pre3-3
- fix compilation of some buggy drivers
- fix build on sparc64

* Thu Mar 16 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre2-3
- replace iBCS with abi, remove patches
- port abi to 2.3.99pre2-3
- fix packaging bug (ksymoops.8* was included in kernel-utils AND
  kernel-pcmcia-cs)
- add devfsd
- fix compilation on alpha (fix various kernel bugs and work
  around a compiler bug)
